@@ -1052,17 +1052,17 @@ void MyMoneyGncReader::convertPrice (const GncPrice *gpr) {
   Q_CHECK_PTR (gpr);
   // add this to our price history
   if (m_priceCount == 0) signalProgress (0, 1, i18n("Loading prices..."));
+  MyMoneyMoney rate = convBadValue (gpr->value());
   if (gpr->commodity()->isCurrency()) {
     MyMoneyPrice exchangeRate (gpr->commodity()->id().utf8(), gpr->currency()->id().utf8(),
-                               gpr->priceDate(), MyMoneyMoney(gpr->value()), i18n("Imported History"));
+                               gpr->priceDate(), rate, i18n("Imported History"));
     m_storage->addPrice (exchangeRate);
   } else {
     MyMoneySecurity e = m_storage->security(m_mapEquities[gpr->commodity()->id().utf8()]);
     if (gncdebug) qDebug ("Searching map, key = %s, found id = %s",
                             gpr->commodity()->id().latin1(), e.id().data());
     e.setTradingCurrency (gpr->currency()->id().utf8());
-    MyMoneyMoney priceValue(gpr->value());
-    MyMoneyPrice stockPrice(e.id(), gpr->currency()->id().utf8(), gpr->priceDate(), priceValue, i18n("Imported History"));
+    MyMoneyPrice stockPrice(e.id(), gpr->currency()->id().utf8(), gpr->priceDate(), rate, i18n("Imported History"));
     m_storage->addPrice (stockPrice);
     m_storage->modifySecurity(e);
   }
@@ -1201,6 +1201,7 @@ void MyMoneyGncReader::convertTransaction (const GncTransaction *gtx) {
   tx.setEntryDate (gtx->dateEntered());
   tx.setPostDate (gtx->datePosted());
   m_txDatePosted = tx.postDate(); // save for use in splits
+  m_txChequeNo = gtx->no(); // ditto
   tx.setCommodity (gtx->currency().utf8());
   m_txCommodity = tx.commodity(); // save in storage, maybe needed for Orphan accounts
   // process splits
@@ -1218,7 +1219,7 @@ void MyMoneyGncReader::convertTransaction (const GncTransaction *gtx) {
   while (!m_splitList.isEmpty()) {
     split = *it;
     if (m_potentialTransfer) split.setAction(MyMoneySplit::ActionTransfer);
-    split.setNumber(gtx->no());
+    //split.setNumber(gtx->no());
     // Arbitrarily, save the first non-null split memo as the memo for the whole tx
     // I think this is necessary because txs with just 2 splits (the majority)
     // are not viewable as split transactions in kmm so the split memo is not seen
@@ -1268,17 +1269,22 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
   split.setMemo(gsp->memo());
   // accountId
   split.setAccountId (kmmAccountId);
+  // cheque no
+  split.setNumber (m_txChequeNo);
   // value and quantity
-  MyMoneyMoney splitValue (0);
-  if (gsp->value() != QString("-1/0")) { // treat gnc invalid value as zero
-   splitValue = gsp->value();
- } else {
+  MyMoneyMoney splitValue (convBadValue (gsp->value()));
+  if (gsp->value() == QString("-1/0")) { // treat gnc invalid value as zero
    // it's not quite a consistency check, but easier to treat it as such
    postMessage ("CC", 4, splitAccount.name().latin1(), m_txDatePosted.toString(Qt::ISODate).latin1());
- }
-  MyMoneyMoney splitQuantity(gsp->qty());
+  }
+  MyMoneyMoney splitQuantity(convBadValue(gsp->qty()));
   split.setValue (splitValue);
-  split.setShares (splitQuantity);
+  // if split currency = tx currency, set shares = value (14/10/05)
+  if (splitAccount.currencyId() == m_txCommodity) {
+    split.setShares (splitValue);
+  } else {
+    split.setShares (splitQuantity);
+  }
 
   // in kmm, the first split is important. in this routine we will
   // save the splits in our split list with the priority:
@@ -1320,8 +1326,6 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
       }
     } else { // not stock
       if (split.value().isNegative()) {
-        split.setAction (MyMoneySplit::ActionDeposit);
-      } else {
         bool isNumeric = false;
         if (!split.number().isEmpty()) {
           split.number().toLong(&isNumeric);    // No QString.isNumeric()??
@@ -1331,14 +1335,16 @@ void MyMoneyGncReader::convertSplit (const GncSplit *gsp) {
         } else {
           split.setAction (MyMoneySplit::ActionWithdrawal);
         }
+      } else {
+        split.setAction (MyMoneySplit::ActionDeposit);
       }
     }
     m_splitList.append(split);
     break;
   case MyMoneyAccount::Liability:
     split.value().isNegative() ?
-    split.setAction (MyMoneySplit::ActionWithdrawal) :
-    split.setAction (MyMoneySplit::ActionDeposit);
+        split.setAction (MyMoneySplit::ActionWithdrawal) :
+        split.setAction (MyMoneySplit::ActionDeposit);
     m_liabilitySplitList.append(split);
     break;
   default:
@@ -1379,14 +1385,14 @@ MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString s
     convertTemplateSplit (schedName, static_cast<const GncTemplateSplit *>(gtx->getSplit (i)));
   }
   // determine the action type for the splits and link them to the template tx
-  QCString negativeActionType, positiveActionType;
-  if (!m_splitList.isEmpty()) { // if there are asset splits
+  /*QCString negativeActionType, positiveActionType;
+  if (!m_splitList.isEmpty()) { // if there are asset splits 
     positiveActionType = MyMoneySplit::ActionDeposit;
     negativeActionType = MyMoneySplit::ActionWithdrawal;
   } else { // if there are liability splits
     positiveActionType = MyMoneySplit::ActionWithdrawal;
     negativeActionType = MyMoneySplit::ActionDeposit;
-  }
+} */
   if (!m_otherSplitList.isEmpty()) m_potentialTransfer = false; // tfrs can occur only between assets and asset/liabilities
   m_splitList += m_liabilitySplitList += m_otherSplitList;
   // the splits are in order in splitList. Transfer them to the tx
@@ -1400,10 +1406,12 @@ MyMoneyTransaction MyMoneyGncReader::convertTemplateTransaction (const QString s
     if (m_potentialTransfer) {
       split.setAction(MyMoneySplit::ActionTransfer);
     } else {
-      if (split.value() <= MyMoneyMoney (0)) {
-        split.setAction (negativeActionType);
+      if (split.value().isNegative()) {
+        //split.setAction (negativeActionType);
+        split.setAction (MyMoneySplit::ActionWithdrawal);
       } else {
-        split.setAction (positiveActionType);
+        //split.setAction (positiveActionType);
+        split.setAction (MyMoneySplit::ActionDeposit);
       }
     }
     split.setNumber(gtx->no()); // set cheque no (or equivalent description)
@@ -1471,6 +1479,7 @@ void MyMoneyGncReader::convertTemplateSplit (const QString schedName, const GncT
       }
       // validate numeric, work out sign
       MyMoneyMoney exFormula (0);
+      exFormula.setNegativeMonetarySignPosition (MyMoneyMoney::BeforeQuantityMoney);
       QString numericTest;
       char crdr;
       if (!gncCreditFormula.isEmpty()) {
@@ -1485,7 +1494,7 @@ void MyMoneyGncReader::convertTemplateSplit (const QString schedName, const GncT
       if (v.validate (numericTest, pos) == QValidator::Acceptable) {
         switch (crdr) {
           case 'C':
-            exFormula = "-" + numericTest; break;
+            exFormula = QString ("-" + numericTest); break;
           case 'D':
             exFormula = numericTest;
         }
@@ -1523,6 +1532,12 @@ void MyMoneyGncReader::convertTemplateSplit (const QString schedName, const GncT
   }
   splitAccount = m_storage->account (kmmAccountId);
   split.setAccountId (kmmAccountId);
+  // if split currency = tx currency, set shares = value (14/10/05)
+  if (splitAccount.currencyId() == m_txCommodity) {
+    split.setShares (split.value());
+  } /* else {  //FIXME: scheduled currency or investment tx needs to be investigated
+    split.setShares (splitQuantity);
+  }  */
   // add the split to one of the lists
   switch (splitAccount.accountGroup()) {
   case MyMoneyAccount::Asset:
