@@ -146,7 +146,6 @@ allow us to test the structure, if not the data content, of the file.
 
 #include <qdatastream.h>
 class QIODevice;
-#include <qmessagebox.h>
 #include <qobject.h>
 #include <qvaluelist.h>
 #include <qptrlist.h>
@@ -732,7 +731,9 @@ protected:
   bool developerDebug;
 private:
   void setOptions (); // to set user options, with a dialog eventually
-  void setFileHideFactor ();
+  void setFileHideFactor (); 
+  // the following handles the gnucash indicator for a bad value (-1/0) which causes us probs
+  const QString convBadValue (QString gncValue) const {return (gncValue == "-1/0" ? "0/1" : gncValue); };
 #ifndef _GNCFILEANON
   MyMoneyTransaction convertTemplateTransaction (const QString, const GncTransaction *);
   void convertTemplateSplit (const QString, const GncTemplateSplit *);
@@ -781,6 +782,7 @@ private:
   QCString m_txCommodity; // save commodity for current transaction
   QString m_txPayeeId;    // gnc has payee at tx level, we need it at split level
   QDate m_txDatePosted;   // ditto for post date
+  QString m_txChequeNo;    // ditto for cheque number
   /** In kmm, the order of splits is critical to some operations. These
     * areas will hold the splits until we've read them all */
   QValueList<MyMoneySplit> m_splitList, m_liabilitySplitList, m_otherSplitList;
