@@ -796,6 +796,12 @@ void MyMoneyQifReader::processTransactionEntry(void)
           kdDebug(2) << "Line " << m_linenumber << ": Cannot transfer to an investment account. Transaction ignored." << endl;
           return;
         }
+	
+        if ( account.id() == m_account.id() )
+        {
+          kdDebug(2) << "Line " << m_linenumber << ": Cannot transfer to the same account. Transfer ignored." << endl;
+          accountId = QCString();
+        }
         
       } catch (MyMoneyException *e) {
         kdDebug(2) << "Line " << m_linenumber << ": Account with id " << accountId.data() << " not found" << endl;
@@ -858,6 +864,11 @@ void MyMoneyQifReader::processTransactionEntry(void)
             kdDebug(2) << "Line " << m_linenumber << ": Cannot transfer to an investment account. Transaction ignored." << endl;
             return;
           }
+          if ( account.id() == m_account.id() )
+          {
+            kdDebug(2) << "Line " << m_linenumber << ": Cannot transfer to the same account. Transfer ignored." << endl;
+            accountId = QCString();
+          }
         
         } catch (MyMoneyException *e) {
           kdDebug(2) << "Line " << m_linenumber << ": Account with id " << accountId.data() << " not found" << endl;
@@ -1091,7 +1102,7 @@ void MyMoneyQifReader::processInvestmentTransactionEntry()
     
     // If the security is not known, notify the user
     // TODO: A "SelectOrCreateAccount" interface for investments
-    KMessageBox::information(0, i18n("This investment account does not contain the '%1' security.  "
+    KMessageBox::information(0, i18n("This investment account does not contain the \"%1\" security.  "
                                       "Transactions involving this security will be ignored.").arg(securityname),
                                 i18n("Security not found"),
                                 QString("MissingSecurity%1").arg(securityname.stripWhiteSpace()));
