@@ -49,11 +49,12 @@ WebPriceQuote::WebPriceQuote( QObject* _parent, const char* _name ):
 WebPriceQuote::~WebPriceQuote()
 {
 }
-  
-bool WebPriceQuote::launch( const QString& _symbol, const QString& _sourcename )
+
+bool WebPriceQuote::launch( const QString& _symbol, const QString& _id, const QString& _sourcename )
 {
   bool result = true;
   m_symbol = _symbol;
+  m_id = _id;
 
   // if we're running normally, with a UI, we can just get these the normal way,
   // from the config file
@@ -62,7 +63,7 @@ bool WebPriceQuote::launch( const QString& _symbol, const QString& _sourcename )
     QString sourcename = _sourcename;
     if ( sourcename.isEmpty() )
       sourcename = "Yahoo";
-      
+
     if ( quoteSources().contains(sourcename) )
       m_source = WebPriceQuoteSource(sourcename);
     else
@@ -77,16 +78,16 @@ bool WebPriceQuote::launch( const QString& _symbol, const QString& _sourcename )
     else
       m_source = defaultQuoteSources()[_sourcename];
   }
-  
+
   KURL url;
-  
+
   // if the source has room for TWO symbols..
   if ( m_source.m_url.contains("%2") )
   {
     // this is a two-symbol quote.  split the symbol into two.  valid symbol
     // characters are: 0-9, A-Z and the dot.  anything else is a separator
-    QRegExp splitrx("([0-9a-z\\.]+)[^a-z0-9]+([0-9a-z\\.]+)",false /*case sensitive*/);    
-    
+    QRegExp splitrx("([0-9a-z\\.]+)[^a-z0-9]+([0-9a-z\\.]+)",false /*case sensitive*/);
+
     // if we've truly found 2 symbols delimited this way...
     if ( splitrx.search(m_symbol) != -1 )
       url = KURL::fromPathOrURL(m_source.m_url.arg(splitrx.cap(1),splitrx.cap(2)));
@@ -106,7 +107,7 @@ bool WebPriceQuote::launch( const QString& _symbol, const QString& _sourcename )
   // still be useful
   if ( ! kapp && ! url.isLocalFile() )
     url = KURL::fromPathOrURL("/usr/bin/wget -O - " + url.prettyURL());
-    
+
   if ( url.isLocalFile() )
   {
     emit status(QString("Executing %1...").arg(url.path()));
@@ -120,7 +121,7 @@ bool WebPriceQuote::launch( const QString& _symbol, const QString& _sourcename )
     KProcess::RunMode mode = KProcess::NotifyOnExit;
     if ( ! kapp )
       mode = KProcess::Block;
-    
+
     if(m_filter.start(mode, KProcess::All))
     {
       result = true;
@@ -130,7 +131,7 @@ bool WebPriceQuote::launch( const QString& _symbol, const QString& _sourcename )
     {
       emit error(QString("Unable to launch: %1").arg(url.path()));
       slotParseQuote(QString());
-    } 
+    }
   }
   else
   {
@@ -170,7 +171,7 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
   bool gotdate = false;
 
 //    kdDebug(2) << "WebPriceQuote::slotParseQuote( " << _quotedata << " ) " << endl;
-  
+
   if ( ! quotedata.isEmpty() )
   {
     //
@@ -181,10 +182,10 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
     quotedata.remove(QRegExp("<[^>]*>"));
 
     // &...;'s
-    quotedata.replace(QRegExp("&[^;]+;")," ");
-    
+    quotedata.replace(QRegExp("&\\w+;")," ");
+
     // Extra white space
-    quotedata = quotedata.simplifyWhiteSpace();      
+    quotedata = quotedata.simplifyWhiteSpace();
 
 #ifdef KMM_DEBUG
     // Enable to get a look at the data coming back from the source after it's stripped
@@ -206,14 +207,36 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
     if(priceRegExp.search(quotedata)> -1)
     {
       gotprice = true;
-      m_price = priceRegExp.cap(1).toDouble();
-      emit status(i18n("Price found: %1").arg(m_price));
+
+      // Deal with european quotes that come back as X.XXX,XX or XX,XXX
+      //
+      // We will make the assumption that ALL prices have a decimal separator.
+      // So "1,000" always means 1.0, not 1000.0.
+      //
+      // Remove all non-digits from the price string except the last one, and
+      // set the last one to a period.
+      QString pricestr = priceRegExp.cap(1);
+
+      int pos = pricestr.findRev(QRegExp("\\D"));
+      if ( pos > 0 )
+      {
+        pricestr[pos] = '.';
+        pos = pricestr.findRev(QRegExp("\\D"),pos-1);
+      }
+      while ( pos > 0 )
+      {
+        pricestr.remove(pos,1);
+        pos = pricestr.findRev(QRegExp("\\D"),pos);
+      }
+
+      m_price = pricestr.toDouble();
+      emit status(i18n("Price found: %1 (%2)").arg(pricestr).arg(m_price));
     }
 
     if(dateRegExp.search(quotedata) > -1)
     {
       QString datestr = dateRegExp.cap(1);
-      
+
       MyMoneyDateFormat dateparse(m_source.m_dateformat);
       try
       {
@@ -230,7 +253,7 @@ void WebPriceQuote::slotParseQuote(const QString& _quotedata)
 
     if ( gotprice && gotdate )
     {
-      emit quote( m_symbol, m_date, m_price );
+      emit quote( m_id, m_symbol, m_date, m_price );
     }
     else
     {
@@ -243,7 +266,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
 {
   QMap<QString,WebPriceQuoteSource> result;
 
-  result["Yahoo"] = WebPriceQuoteSource("Yahoo", 
+  result["Yahoo"] = WebPriceQuoteSource("Yahoo",
     "http://finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d1",
     "\"([^,\"]*)\",.*",  // symbolregexp
     "[^,]*,([^,]*),.*", // priceregexp
@@ -251,7 +274,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "%m %d %y" // dateformat
   );
 
-  result["Yahoo Currency"] = WebPriceQuoteSource("Yahoo Currency", 
+  result["Yahoo Currency"] = WebPriceQuoteSource("Yahoo Currency",
     "http://finance.yahoo.com/d/quotes.csv?s=%1%2=X&f=sl1d1",
     "\"([^,\"]*)\",.*",  // symbolregexp
     "[^,]*,([^,]*),.*", // priceregexp
@@ -259,7 +282,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "%m %d %y" // dateformat
   );
 
-  result["Yahoo UK"] = WebPriceQuoteSource("Yahoo UK", 
+  result["Yahoo UK"] = WebPriceQuoteSource("Yahoo UK",
     "http://uk.finance.yahoo.com/d/quotes.csv?s=%1&f=sl1d1",
     "\"([^,\"]*)\",.*",  // symbolregexp
     "[^,]*,([^,]*),.*", // priceregexp
@@ -267,7 +290,7 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "%m %d %y" // dateformat
   );
 
-  result["Globe & Mail"] = WebPriceQuoteSource("Globe & Mail", 
+  result["Globe & Mail"] = WebPriceQuoteSource("Globe & Mail",
     "http://globefunddb.theglobeandmail.com/gishome/plsql/gis.price_history?pi_fund_id=%1",
     QString(),  // symbolregexp
     "Reinvestment Price \\w+ \\d+, \\d+ (\\d+\\.\\d+)", // priceregexp
@@ -275,14 +298,48 @@ QMap<QString,WebPriceQuoteSource> WebPriceQuote::defaultQuoteSources(void)
     "%m %d %y" // dateformat
   );
 
-  result["MSN.CA"] = WebPriceQuoteSource("MSN.CA", 
+  result["MSN.CA"] = WebPriceQuoteSource("MSN.CA",
     "http://ca.moneycentral.msn.com/investor/quotes/quotes.asp?symbol=%1",
     QString(),  // symbolregexp
     "Net Asset Value (\\d+\\.\\d+)", // priceregexp
     "NAV update (\\d+\\D+\\d+\\D+\\d+)", // dateregexp
     "%d %m %y" // dateformat
   );
-    
+
+  result["VWD.DE"] = WebPriceQuoteSource("VWD.DE",
+    "http://www.finanztreff.de/ftreff/kurse_einzelkurs_uebersicht.htm?s=%1",
+    QString(),  // symbolregexp
+    "[Kurs|Realtime]: \\d+\\D+\\d+\\D+\\d+ ([0-9.]+,\\d+)", // priceregexp
+    "Jahreschart (\\d+\\D+\\d+\\D+\\d+)", // dateregexp
+    "%d %m %y" // dateformat
+  );
+
+  // The following two price sources were contributed by
+  // Marc Zahnlecker <tf2k@users.sourceforge.net>
+
+  result["Wallstreet-Online.DE (Default)"] = WebPriceQuoteSource("Wallstreet-Online.DE (Default)",
+    "http://www.wallstreet-online.de/si/?k=%1&spid=ws",
+    "Symbol:(\\w+)",  // symbolregexp
+    "Letzter Kurs: ([0-9.]+,\\d+)", // priceregexp
+    ", (\\d+\\D+\\d+\\D+\\d+)", // dateregexp
+    "%d %m %y" // dateformat
+  );
+
+  // (tf2k) The "mpid" is I think the market place id. In this case five
+  // stands for Hamburg.
+  //
+  // Here the id for several market places: 2 Frankfurt, 3 Berlin, 4
+  // Dsseldorf, 5 Hamburg, 6 Mnchen/Munich, 7 Hannover, 9 Stuttgart, 10
+  // Xetra, 32 NASDAQ, 36 NYSE
+
+  result["Wallstreet-Online.DE (Hamburg)"] = WebPriceQuoteSource("Wallstreet-Online.DE (Hamburg)",
+    "http://www.wallstreet-online.de/si/?k=%1&spid=ws&mpid=5",
+    "Symbol:(\\w+)",  // symbolregexp
+    "Letzter Kurs: ([0-9.]+,\\d+)", // priceregexp
+    ", (\\d+\\D+\\d+\\D+\\d+)", // dateregexp
+    "%d %m %y" // dateformat
+  );
+
   return result;
 }
 
@@ -312,7 +369,7 @@ QStringList WebPriceQuote::quoteSources(void)
     QString priceRegExp(kconfig->readEntry("PriceRegex","[^,]*,([^,]*),.*"));
     QString dateRegExp(kconfig->readEntry("DateRegex","[^,]*,[^,]*,\"([^\"]*)\""));
     kconfig->deleteGroup("Online Quotes Options");
-    
+
     groups += "Old Source";
     kconfig->setGroup(QString("Online-Quote-Source-%1").arg("Old Source"));
     kconfig->writeEntry("URL", url);
@@ -337,7 +394,7 @@ QStringList WebPriceQuote::quoteSources(void)
     }
     ++it_source;
   }
-    
+
   return groups;
 }
 
@@ -405,7 +462,7 @@ void WebPriceQuoteProcess::slotReceivedDataFromFilter(KProcess* /*_process*/, ch
 {
   QByteArray data;
   data.duplicate(_pcbuffer, _nbufferlen);
-  
+
 //   kdDebug(2) << "WebPriceQuoteProcess::slotReceivedDataFromFilter(): " << QString(data) << endl;
 
   m_string += QString(data);
@@ -414,7 +471,7 @@ void WebPriceQuoteProcess::slotReceivedDataFromFilter(KProcess* /*_process*/, ch
 void WebPriceQuoteProcess::slotProcessExited(KProcess*)
 {
 //   kdDebug(2) << "WebPriceQuoteProcess::slotProcessExited()" << endl;
-  
+
   emit processExited(m_string);
   m_string.truncate(0);
 }
@@ -425,7 +482,7 @@ void WebPriceQuoteProcess::slotProcessExited(KProcess*)
 
 // In 'strict' mode, this is designed to be compatable with the QIF profile date
 // converter.  However, that converter deals with the concept of an apostrophe
-// format in a way I don't understand.  So for the moment, they are 99% 
+// format in a way I don't understand.  So for the moment, they are 99%
 // compatable, waiting on that issue. (acejones)
 
 QDate MyMoneyDateFormat::convertString(const QString& _in, bool _strict, unsigned _centurymidpoint) const
@@ -433,31 +490,31 @@ QDate MyMoneyDateFormat::convertString(const QString& _in, bool _strict, unsigne
   //
   // Break date format string into component parts
   //
-  
+
   QRegExp formatrex("%([mdy]+)(\\W+)%([mdy]+)(\\W+)%([mdy]+)",false /* case sensitive */);
   if ( formatrex.search(m_format) == -1 )
   {
     throw new MYMONEYEXCEPTION("Invalid format string");
   }
-  
+
   QStringList formatParts;
   formatParts += formatrex.cap(1);
   formatParts += formatrex.cap(3);
   formatParts += formatrex.cap(5);
-  
+
   QStringList formatDelimiters;
   formatDelimiters += formatrex.cap(2);
   formatDelimiters += formatrex.cap(4);
-  
+
   //
   // Break input string up into component parts,
   // using the delimiters found in the format string
   //
-  
+
   QRegExp inputrex;
   inputrex.setCaseSensitive(false);
-  
-  // strict mode means we must enforce the delimiters as specified in the 
+
+  // strict mode means we must enforce the delimiters as specified in the
   // format.  non-strict allows any delimiters
   if ( _strict )
     inputrex.setPattern(QString("(\\w+)%1(\\w+)%2(\\w+)").arg(formatDelimiters[0],formatDelimiters[1]));
@@ -477,7 +534,7 @@ QDate MyMoneyDateFormat::convertString(const QString& _in, bool _strict, unsigne
   //
   // Convert the scanned parts into actual date components
   //
-  
+
   unsigned day = 0, month = 0, year = 0;
   bool ok;
   QRegExp digitrex("(\\d+)");
@@ -508,49 +565,49 @@ QDate MyMoneyDateFormat::convertString(const QString& _in, bool _strict, unsigne
           ++i;
         }
       }
-      
+
       if ( month < 1 || month > 12 )
         throw new MYMONEYEXCEPTION(QString("Invalid month entry: %1").arg(*it_scanned));
-      
+
       break;
     case 'y':
       if ( _strict && (*it_scanned).length() != (*it_format).length())
         throw new MYMONEYEXCEPTION(QString("Length of year (%1) does not match expected length (%2).")
                 .arg(*it_scanned,*it_format));
-      
+
       year = (*it_scanned).toUInt(&ok);
-      
+
       if (!ok)
         throw new MYMONEYEXCEPTION(QString("Invalid year entry: %1").arg(*it_scanned));
-        
+
       //
       // 2-digit year case
       //
-      // this algorithm will pick a year within +/- 50 years of the 
+      // this algorithm will pick a year within +/- 50 years of the
       // centurymidpoint parameter.  i.e. if the midpoint is 2000,
       // then 0-49 will become 2000-2049, and 50-99 will become 1950-1999
       if ( year < 100 )
       {
         unsigned centuryend = _centurymidpoint + 50;
         unsigned centurybegin = _centurymidpoint - 50;
-        
+
         if ( year < centuryend % 100 )
           year += 100;
         year += centurybegin - centurybegin % 100;
       }
-      
+
       if ( year < 1900 )
         throw new MYMONEYEXCEPTION(QString("Invalid year (%1)").arg(year));
-      
+
       break;
     default:
       throw new MYMONEYEXCEPTION("Invalid format character");
     }
-  
+
     ++it_scanned;
-    ++it_format; 
+    ++it_format;
   }
-  
+
   QDate result(year,month,day);
   if ( ! result.isValid() )
     throw new MYMONEYEXCEPTION(QString("Invalid date (yr%1 mo%2 dy%3)").arg(year).arg(month).arg(day));
@@ -580,20 +637,20 @@ convertertest::QuoteReceiver::~QuoteReceiver()
 void convertertest::QuoteReceiver::slotGetQuote(const QString&,const QDate& d, const double& m)
 {
 //   kdDebug(2) << "test::QuoteReceiver::slotGetQuote( , " << d << " , " << m.toString() << " )" << endl;
- 
+
   m_price = MyMoneyMoney(m);
   m_date = d;
 }
 void convertertest::QuoteReceiver::slotStatus(const QString& msg)
 {
 //   kdDebug(2) << "test::QuoteReceiver::slotStatus( " << msg << " )" << endl;
-  
+
   m_statuses += msg;
 }
 void convertertest::QuoteReceiver::slotError(const QString& msg)
 {
 //   kdDebug(2) << "test::QuoteReceiver::slotError( " << msg << " )" << endl;
-  
+
   m_errors += msg;
 }
 
