@@ -176,7 +176,8 @@ const KURL KMyMoney2App::lastOpenedURL(void)
     url = readLastUsedFile();
   }
 
-  slotStatusMsg(i18n("Ready."));
+  ready();
+
   return url;
 }
 
@@ -266,8 +267,8 @@ void KMyMoney2App::initStatusBar()
   ///////////////////////////////////////////////////////////////////
   // STATUSBAR
 
-  // TODO: add your own items you need for displaying current application status.
-  statusBar()->insertItem(i18n("Ready."), ID_STATUS_MSG);
+  statusBar()->insertItem("", ID_STATUS_MSG);
+  ready();
 
   // Initialization of progress bar taken from KDevelop ;-)
   progressBar = new KProgress(statusBar());
@@ -335,6 +336,9 @@ void KMyMoney2App::resizeEvent(QResizeEvent* ev)
 
 bool KMyMoney2App::queryClose()
 {
+  if(!isReady())
+    return false;
+
   if (myMoneyView->dirty()) {
     int ans = KMessageBox::warningYesNoCancel(this, i18n("KMyMoney file needs saving.  Save ?"));
     if (ans==KMessageBox::Cancel)
@@ -607,7 +611,8 @@ void KMyMoney2App::slotFileClose()
 
 void KMyMoney2App::slotFileQuit()
 {
-  QString prevMsg = slotStatusMsg(i18n("Exiting..."));
+  // don't modify the status message here as this will prevent quit from working!!
+  // See the beginning of queryClose() and isReady() why. Thomas Baumgart 2005-10-17
 
   KMainWindow* w = 0;
 
@@ -626,9 +631,6 @@ void KMyMoney2App::slotFileQuit()
 
   } else
       kapp->quit();
-
-  // in case we don't really quit
-  slotStatusMsg(prevMsg);
 }
 
 void KMyMoney2App::slotViewToolBar()
@@ -679,6 +681,15 @@ const QString KMyMoney2App::slotStatusMsg(const QString &text)
   return msg;
 }
 
+void KMyMoney2App::ready(void)
+{
+  slotStatusMsg(i18n("Ready."));
+}
+
+bool KMyMoney2App::isReady(void)
+{
+  return m_statusMsg == i18n("Ready.");
+}
 
 void KMyMoney2App::slotStatusProgressBar(const int current, const int total)
 {
@@ -725,11 +736,12 @@ void KMyMoney2App::slotFileViewPersonal()
 
   if ( !myMoneyView->fileOpen() ) {
 
-    KMessageBox::information(this, i18n("No MyMoneyFile open"));
+    KMessageBox::information(this, i18n("No KMyMoney file open"));
     return;
   }
 
   myMoneyView->viewPersonal();
+  updateCaption();
 
   slotStatusMsg(prevMsg);
 }
@@ -738,7 +750,7 @@ void KMyMoney2App::slotFileFileInfo()
 {
   if ( !myMoneyView->fileOpen() ) {
 
-    KMessageBox::information(this, i18n("No MyMoneyFile open"));
+    KMessageBox::information(this, i18n("No KMyMoney file open"));
 
     return;
   }
@@ -899,7 +911,7 @@ void KMyMoney2App::slotQifImportFinished(void)
     m_reader = 0;
   }
   slotStatusProgressBar(-1, -1);
-  slotStatusMsg(i18n("Ready."));
+  ready();
 
   // re-enable all standard widgets
   setEnabled(true);
@@ -908,17 +920,16 @@ void KMyMoney2App::slotQifImportFinished(void)
 void KMyMoney2App::slotGncImport(void)
 {
   if (myMoneyView->fileOpen()) {
-    switch (QMessageBox::question (0, PACKAGE,
-         QObject::tr("You cannot import GnuCash data into an existing file. Do you wish to save this file?"),
-          QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel)) {
-    case QMessageBox::Yes:
+    switch (KMessageBox::questionYesNoCancel (0,
+          i18n("You cannot import GnuCash data into an existing file. Do you wish to save this file?"), PACKAGE)) {
+    case KMessageBox::Yes:
       slotFileSave();
       break;
-    case QMessageBox::No:
+    case KMessageBox::No:
       myMoneyView->closeFile();
       fileName = KURL();
       break;
-    case QMessageBox::Cancel:
+    default:
       return;
     }
   }
@@ -1203,7 +1214,7 @@ void KMyMoney2App::slotStatementImportFinished(void)
     m_smtReader = 0;
   }
   slotStatusProgressBar(-1, -1);
-  slotStatusMsg(i18n("Ready."));
+  ready();
 
   // re-enable all standard widgets
   setEnabled(true);
@@ -1371,7 +1382,8 @@ void KMyMoney2App::slotProcessExited()
               proc.start();
             } else {
               m_backupState = BACKUP_IDLE;
-              progressCallback(-1, -1, i18n("Ready."));
+              progressCallback(-1, -1, QString());
+              ready();
             }
           }
         }
@@ -1396,7 +1408,8 @@ void KMyMoney2App::slotProcessExited()
 
         } else {
           m_backupState = BACKUP_IDLE;
-          progressCallback(-1, -1, i18n("Ready."));
+          progressCallback(-1, -1, QString());
+          ready();
         }
       }
       break;
@@ -1415,7 +1428,8 @@ void KMyMoney2App::slotProcessExited()
           progressCallback(300, 0, i18n("Done"));
           KMessageBox::information(this, i18n("File successfully backed up"), i18n("Backup"));
           m_backupState = BACKUP_IDLE;
-          progressCallback(-1, -1, i18n("Ready."));
+          progressCallback(-1, -1, QString());
+          ready();
         }
       } else {
         qDebug("cp exit status is %d", proc.exitStatus());
@@ -1433,7 +1447,8 @@ void KMyMoney2App::slotProcessExited()
 
         } else {
           m_backupState = BACKUP_IDLE;
-          progressCallback(-1, -1, i18n("Ready."));
+          progressCallback(-1, -1, QString());
+          ready();
         }
       }
       break;
@@ -1449,12 +1464,14 @@ void KMyMoney2App::slotProcessExited()
         KMessageBox::information(this, i18n("Error unmounting device"), i18n("Backup"));
       }
       m_backupState = BACKUP_IDLE;
-      progressCallback(-1, -1, i18n("Ready."));
+      progressCallback(-1, -1, QString());
+      ready();
       break;
 
     default:
       qWarning("Unknown state for backup operation!");
-      progressCallback(-1, -1, i18n("Ready."));
+      progressCallback(-1, -1, QString());
+      ready();
       break;
   }
 }
@@ -1622,11 +1639,11 @@ void KMyMoney2App::slotPriceDialog(void)
 
 void KMyMoney2App::slotFileConsitencyCheck(void)
 {
-  QString prevMsg = slotStatusMsg(i18n("Running consitency check..."));
+  QString prevMsg = slotStatusMsg(i18n("Running consistency check..."));
 
   QStringList msg = MyMoneyFile::instance()->consistencyCheck();
 
-  KMessageBox::warningContinueCancelList(0, "Result", msg, i18n("Consitency check result"));
+  KMessageBox::warningContinueCancelList(0, "Result", msg, i18n("Consistency check result"));
 
   slotStatusMsg(prevMsg);
   updateCaption();
@@ -1641,7 +1658,10 @@ void KMyMoney2App::slotCheckSchedules(void)
     MyMoneyFile::instance()->suspendNotify(true);
     QString prevMsg = slotStatusMsg(i18n("Checking for overdue schedules..."));
     MyMoneyFile *file = MyMoneyFile::instance();
-    QDate checkDate = QDate::currentDate().addDays(kconfig->readNumEntry("CheckSchedulePreview", 0));
+    int checkDays = kconfig->readNumEntry("CheckSchedulePreview", 0);
+    if(checkDays < 0)
+      checkDays = 0;
+    QDate checkDate = QDate::currentDate().addDays(checkDays);
 
     QValueList<MyMoneySchedule> scheduleList =  file->scheduleList();
     QValueList<MyMoneySchedule>::Iterator it;
@@ -1743,7 +1763,7 @@ bool KMyMoney2App::slotCommitTransaction(const MyMoneySchedule& sched, const QDa
       QClipboard *cb = QApplication::clipboard();
       cb->setText(d, QClipboard::Clipboard);
       QMessageBox::information( 0, PACKAGE,
-        i18n("Unable to autoEnter schedule %1. Please check manually\n"
+        i18n("Unable to autoEnter schedule %1. Please check manually!\n"
   "Debug data has been copied to clipboard; please paste into an\n"
   "email and send to kmymoney2-developer@lists.sourceforge.net").arg (schedule.name()));
       return (false);
