@@ -51,7 +51,7 @@ void MyMoneyFileTest::testEmptyConstructor() {
 
 	CPPUNIT_ASSERT(m->institutionCount() == 0);
 	CPPUNIT_ASSERT(m->dirty() == false);
-	CPPUNIT_ASSERT(m->accountCount() == 4);
+	CPPUNIT_ASSERT(m->accountCount() == 5);
 }
 
 void MyMoneyFileTest::testAddOneInstitution() {
@@ -345,7 +345,7 @@ void MyMoneyFileTest::testAddAccounts() {
 
 	storage->m_dirty = false;
 
-	CPPUNIT_ASSERT(m->accountCount() == 4);
+	CPPUNIT_ASSERT(m->accountCount() == 5);
 
 	institution = m->institution("I000001");
 	CPPUNIT_ASSERT(institution.id() == "I000001");
@@ -363,7 +363,7 @@ void MyMoneyFileTest::testAddAccounts() {
 		observer->reset();
 		hierarchyObserver->reset();
 		m->addAccount(a, parent);
-		CPPUNIT_ASSERT(m->accountCount() == 5);
+		CPPUNIT_ASSERT(m->accountCount() == 6);
 		CPPUNIT_ASSERT(a.parentAccountId() == "AStd::Asset");
 		CPPUNIT_ASSERT(a.id() == "A000001");
 		CPPUNIT_ASSERT(a.institutionId() == "I000001");
@@ -427,7 +427,7 @@ void MyMoneyFileTest::testAddAccounts() {
 		CPPUNIT_ASSERT(m->dirty() == true);
 		CPPUNIT_ASSERT(b.id() == "A000002");
 		CPPUNIT_ASSERT(b.parentAccountId() == "AStd::Asset");
-		CPPUNIT_ASSERT(m->accountCount() == 6);
+		CPPUNIT_ASSERT(m->accountCount() == 7);
 
 		institution = m->institution("I000001");
 		CPPUNIT_ASSERT(institution.accountCount() == 1);
@@ -477,7 +477,7 @@ void MyMoneyFileTest::testModifyAccount() {
 		m->modifyAccount(p);
 
 		CPPUNIT_ASSERT(m->dirty() == true);
-		CPPUNIT_ASSERT(m->accountCount() == 6);
+		CPPUNIT_ASSERT(m->accountCount() == 7);
 		CPPUNIT_ASSERT(p.accountType() == MyMoneyAccount::Checkings);
 		CPPUNIT_ASSERT(p.name() == "New account name");
 
@@ -496,7 +496,7 @@ void MyMoneyFileTest::testModifyAccount() {
 		m->modifyAccount(p);
 
 		CPPUNIT_ASSERT(m->dirty() == true);
-		CPPUNIT_ASSERT(m->accountCount() == 6);
+		CPPUNIT_ASSERT(m->accountCount() == 7);
 		CPPUNIT_ASSERT(p.accountType() == MyMoneyAccount::Checkings);
 		CPPUNIT_ASSERT(p.name() == "New account name");
 		CPPUNIT_ASSERT(p.institutionId() == "I000002");
@@ -608,7 +608,7 @@ void MyMoneyFileTest::testRemoveAccount() {
 	try {
 		m->removeAccount(p);
 		CPPUNIT_ASSERT(m->dirty() == true);
-		CPPUNIT_ASSERT(m->accountCount() == 5);
+		CPPUNIT_ASSERT(m->accountCount() == 6);
 		institution = m->institution("I000001");
 		CPPUNIT_ASSERT(institution.accountCount() == 0);
 		CPPUNIT_ASSERT(m->asset().accountList().count() == 1);
@@ -646,7 +646,7 @@ void MyMoneyFileTest::testRemoveAccountTree() {
 		delete e;
 		CPPUNIT_FAIL("Unexpected exception!");
 	}
-	CPPUNIT_ASSERT(m->accountCount() == 5);
+	CPPUNIT_ASSERT(m->accountCount() == 6);
 
 	// make sure it's gone
 	try {
@@ -717,7 +717,7 @@ void MyMoneyFileTest::testAddTransaction () {
 		CPPUNIT_FAIL("Unexpected exception!");
 	}
 
-	CPPUNIT_ASSERT(m->accountCount() == 8);
+	CPPUNIT_ASSERT(m->accountCount() == 9);
 	a = m->account("A000001");
 	CPPUNIT_ASSERT(a.lastModified() == QDate(1,2,3));
 
@@ -1031,14 +1031,14 @@ void MyMoneyFileTest::testBalanceTotal() {
 		t.addSplit(split2);
 		m->addTransaction(t);
 		CPPUNIT_ASSERT(t.id() == "T000000000000000002");
-		CPPUNIT_ASSERT(m->totalBalance("A000001") == -1000);
-		CPPUNIT_ASSERT(m->totalBalance("A000002") == -1000);
+		CPPUNIT_ASSERT(m->totalBalance("A000001") == MyMoneyMoney(-1000));
+		CPPUNIT_ASSERT(m->totalBalance("A000002") == MyMoneyMoney(-1000));
 
 		MyMoneyAccount p = m->account("A000001");
 		MyMoneyAccount q = m->account("A000002");
 		m->reparentAccount(p, q);
-		CPPUNIT_ASSERT(m->totalBalance("A000001") == -1000);
-		CPPUNIT_ASSERT(m->totalBalance("A000002") == -2000);
+		CPPUNIT_ASSERT(m->totalBalance("A000001") == MyMoneyMoney(-1000));
+		CPPUNIT_ASSERT(m->totalBalance("A000002") == MyMoneyMoney(-2000));
 	} catch(MyMoneyException *e) {
 		delete e;
 		CPPUNIT_FAIL("Unexpected exception!");
@@ -1302,3 +1302,238 @@ void MyMoneyFileTest::testAttachedStorage() {
 	CPPUNIT_ASSERT(m->storage() != 0);
 }
 
+void MyMoneyFileTest::testHasAccount() {
+	testAddAccounts();
+
+	MyMoneyAccount a, b;
+	a.setAccountType(MyMoneyAccount::Checkings);
+	a.setName("Account3");
+	b = m->account("A000001");
+	try {
+		m->addAccount(a, b);
+		CPPUNIT_ASSERT(m->accountCount() == 8);
+		CPPUNIT_ASSERT(a.parentAccountId() == "A000001");
+		CPPUNIT_ASSERT(m->hasAccount("A000001", "Account3") == true);
+		CPPUNIT_ASSERT(m->hasAccount("A000001", "Account2") == false);
+		CPPUNIT_ASSERT(m->hasAccount("A000002", "Account3") == false);
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+}
+
+void MyMoneyFileTest::testAddEquityAccount() {
+	MyMoneyAccount i;
+	i.setName("Investment");
+	i.setAccountType(MyMoneyAccount::Investment);
+
+	try {
+		MyMoneyAccount parent = m->asset();
+		observer->reset();
+		hierarchyObserver->reset();
+		m->addAccount(i, parent);
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+
+	// make sure, that only equity accounts can be children to it
+	MyMoneyAccount a;
+	a.setName("Testaccount");
+	QValueList<MyMoneyAccount::accountTypeE> list;
+	list << MyMoneyAccount::Checkings;
+	list << MyMoneyAccount::Savings;
+	list << MyMoneyAccount::Cash;
+	list << MyMoneyAccount::CreditCard;
+	list << MyMoneyAccount::Loan;
+	list << MyMoneyAccount::CertificateDep;
+	list << MyMoneyAccount::Investment;
+	list << MyMoneyAccount::MoneyMarket;
+	list << MyMoneyAccount::Asset;
+	list << MyMoneyAccount::Liability;
+	list << MyMoneyAccount::Currency;
+	list << MyMoneyAccount::Income;
+	list << MyMoneyAccount::Expense;
+	list << MyMoneyAccount::AssetLoan;
+
+	QValueList<MyMoneyAccount::accountTypeE>::Iterator it;
+	for(it = list.begin(); it != list.end(); ++it) {
+		a.setAccountType(*it);
+		try {
+			char	msg[100];
+			observer->reset();
+			hierarchyObserver->reset();
+			m->addAccount(a, i);
+			sprintf(msg, "Can add non-equity type %d to investment", *it);
+			CPPUNIT_FAIL(msg);
+		} catch(MyMoneyException *e) {
+			delete e;
+		}
+	}
+	try {
+		observer->reset();
+		hierarchyObserver->reset();
+		a.setAccountType(MyMoneyAccount::Stock);
+		m->addAccount(a,i);
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+}
+
+void MyMoneyFileTest::testReparentEquity() {
+	testAddEquityAccount();
+	testAddEquityAccount();
+	MyMoneyAccount parent;
+
+	// check the bad cases
+	QValueList<MyMoneyAccount::accountTypeE> list;
+	list << MyMoneyAccount::Checkings;
+	list << MyMoneyAccount::Savings;
+	list << MyMoneyAccount::Cash;
+	list << MyMoneyAccount::CertificateDep;
+	list << MyMoneyAccount::MoneyMarket;
+	list << MyMoneyAccount::Asset;
+	list << MyMoneyAccount::AssetLoan;
+	list << MyMoneyAccount::Currency;
+	parent = m->asset();
+	testReparentEquity(list, parent);
+
+	list.clear();
+	list << MyMoneyAccount::CreditCard;
+	list << MyMoneyAccount::Loan;
+	list << MyMoneyAccount::Liability;
+	parent = m->liability();
+	testReparentEquity(list, parent);
+
+	list.clear();
+	list << MyMoneyAccount::Income;
+	parent = m->income();
+	testReparentEquity(list, parent);
+
+	list.clear();
+	list << MyMoneyAccount::Expense;
+	parent = m->expense();
+	testReparentEquity(list, parent);
+
+	// now check the good case
+	MyMoneyAccount stock = m->account("A000002");
+	MyMoneyAccount inv = m->account("A000003");
+	try {
+		observer->reset();
+		hierarchyObserver->reset();
+		m->reparentAccount(stock, inv);
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+}
+
+void MyMoneyFileTest::testReparentEquity(QValueList<MyMoneyAccount::accountTypeE>& list, MyMoneyAccount& parent)
+{
+	MyMoneyAccount a;
+	a.setName("Testaccount");
+	MyMoneyAccount stock = m->account("A000002");
+
+	QValueList<MyMoneyAccount::accountTypeE>::Iterator it;
+	for(it = list.begin(); it != list.end(); ++it) {
+		a.setAccountType(*it);
+		try {
+			m->addAccount(a, parent);
+			char	msg[100];
+			observer->reset();
+			hierarchyObserver->reset();
+			m->reparentAccount(stock, a);
+			sprintf(msg, "Can reparent stock to non-investment type %d account", *it);
+			CPPUNIT_FAIL(msg);
+		} catch(MyMoneyException *e) {
+			delete e;
+		}
+	}
+}
+
+void MyMoneyFileTest::testBaseCurrency(void)
+{
+	MyMoneySecurity base("EUR", "Euro", QChar(0x20ac));
+	MyMoneySecurity ref;
+
+	// make sure, no base currency is set
+	try {
+		ref = m->baseCurrency();
+		CPPUNIT_ASSERT(ref.id().isEmpty());
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+
+	// make sure, we cannot assign an unknown currency
+	try {
+		m->setBaseCurrency(base);
+		CPPUNIT_FAIL("Missing expected exception");
+	} catch(MyMoneyException *e) {
+		delete e;
+	}
+
+	// add the currency and try again
+	try {
+		m->addCurrency(base);
+		m->setBaseCurrency(base);
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+
+	// make sure, the base currency is set
+	try {
+		ref = m->baseCurrency();
+		CPPUNIT_ASSERT(ref.id() == "EUR");
+		CPPUNIT_ASSERT(ref.name() == "Euro");
+		CPPUNIT_ASSERT(ref.tradingSymbol() == QChar(0x20ac));
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+}
+
+void MyMoneyFileTest::testOpeningBalanceNoBase(void)
+{
+	MyMoneyAccount openingAcc;
+	MyMoneySecurity base;
+
+	try {
+		base = m->baseCurrency();
+		openingAcc = m->openingBalanceAccount(base);
+		CPPUNIT_FAIL("Missing expected exception");
+	} catch(MyMoneyException *e) {
+		delete e;
+	}
+}
+
+void MyMoneyFileTest::testOpeningBalance(void)
+{
+	MyMoneyAccount openingAcc;
+	MyMoneySecurity second("USD", "US Dollar", "$");
+	testBaseCurrency();
+
+	try {
+		openingAcc = m->openingBalanceAccount(m->baseCurrency());
+		CPPUNIT_ASSERT(openingAcc.parentAccountId() == m->equity().id());
+		CPPUNIT_ASSERT(openingAcc.name() == MyMoneyFile::OpeningBalancesPrefix);
+		CPPUNIT_ASSERT(openingAcc.openingBalance() == MyMoneyMoney(0,1));
+		CPPUNIT_ASSERT(openingAcc.openingDate() == QDate::currentDate());
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+
+	// add a second currency
+	try {
+		m->addCurrency(second);
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+
+	QString refName = QString("%1 (%2)").arg(MyMoneyFile::OpeningBalancesPrefix).arg("USD");
+	try {
+		openingAcc = m->openingBalanceAccount(second);
+		CPPUNIT_ASSERT(openingAcc.parentAccountId() == m->equity().id());
+		CPPUNIT_ASSERT(openingAcc.name() == refName);
+		CPPUNIT_ASSERT(openingAcc.openingBalance() == MyMoneyMoney(0,1));
+		CPPUNIT_ASSERT(openingAcc.openingDate() == QDate::currentDate());
+	} catch(MyMoneyException *e) {
+		unexpectedException(e);
+	}
+}
+
