@@ -19,6 +19,10 @@
 #ifndef MYMONEYTRANSACTION_H
 #define MYMONEYTRANSACTION_H
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 // ----------------------------------------------------------------------------
 // QT Includes
 
@@ -33,6 +37,7 @@
 #include "mymoneymoney.h"
 #include "mymoneykeyvaluecontainer.h"
 #include "mymoneysplit.h"
+#include <kmymoney/export.h>
 
 /**
   * This class represents a transaction within the MyMoneyEngine. A transaction
@@ -42,7 +47,7 @@
   * is tolerated by the engine, but in general not a good idea as it is financially
   * wrong.
   */
-class MyMoneyTransaction : public MyMoneyKeyValueContainer
+class KMYMONEY_EXPORT MyMoneyTransaction : public MyMoneyKeyValueContainer
 {
 public:
   MyMoneyTransaction();
@@ -61,16 +66,23 @@ public:
   const QString memo(void) const { return m_memo; };
   const QValueList<MyMoneySplit> splits(void) const { return m_splits; };
   const unsigned int splitCount(void) const { return m_splits.count(); };
+  const QCString commodity(void) const { return m_commodity; };
+  const QString bankID(void) const { return m_bankID; };
 
   // Simple set operations
   void setPostDate(const QDate& date);
   void setEntryDate(const QDate& date);
   void setMemo(const QString& memo);
   void setId(const QString& id) { m_id = id; };
+  void setCommodity(const QCString& commodityId) { m_commodity = commodityId; };
+  void setBankID(const QString& bankID) { m_bankID = bankID; };
 
   bool operator == (const MyMoneyTransaction&) const;
   inline bool operator != (const MyMoneyTransaction& r) const { return !(*this == r); };
-  
+  bool operator< (const MyMoneyTransaction& r) const { return postDate() < r.postDate(); };
+  bool operator<= (const MyMoneyTransaction& r) const { return postDate() <= r.postDate(); };
+  bool operator> (const MyMoneyTransaction& r) const { return postDate() > r.postDate(); };
+
   /**
     * This method is used to extract a split for a given accountId
     * from a transaction. A parameter controls, whether the accountId
@@ -85,6 +97,18 @@ public:
     */
   const MyMoneySplit& splitByAccount(const QCString& accountId, const bool match = true) const;
 
+  /**
+    * This method is essentially the same as the previous method, except that
+    * takes a list of accounts instead of just one.
+    *
+    * @param accountIds the list of accounts to look for
+    * @param match if true, the account Id must match
+    *              if false, the account Id must not match
+    *
+    * @return reference to split within the transaction is returned
+    */
+  const MyMoneySplit& splitByAccount(const QCStringList& accountIds, const bool match = true) const;
+  
   /**
     * This method is used to extract a split from a transaction.
     *
@@ -93,7 +117,7 @@ public:
     * @return reference to split within the transaction is returned
     */
   const MyMoneySplit& splitById(const QCString& splitId) const;
-
+  
   /**
     * This method is used to extract a split for a given payeeId
     * from a transaction.
@@ -108,7 +132,7 @@ public:
     * This method is used to check if the given account is used
     * in any of the splits of this transation
     *
-    * @param id reference to id
+    * @param id account id that should be checked for usage
     */
   const bool accountReferenced(const QCString& id) const;
 
@@ -116,7 +140,7 @@ public:
     * This method is used to add a split to the transaction. The split
     * will be assigned an id. The id member must be empty.
     *
-    * param @split reference to the split that should be added
+    * @param split reference to the split that should be added
     *
     */
   void addSplit(MyMoneySplit& split);
@@ -144,7 +168,7 @@ public:
   const MyMoneyMoney splitSum(void) const;
 
   /**
-    * This method returns information if the transaction 
+    * This method returns information if the transaction
     * contains information of a loan payment or not.
     * Loan payment transactions have at least one
     * split that is identified with a MyMoneySplit::action() of type
@@ -156,7 +180,33 @@ public:
     * @note Upon internal failures, the return value @p false will be used.
     */
   const bool isLoanPayment(void) const;
-  
+
+  /**
+    * This method is used to check if two transactions are identical.
+    * Identical transactions have:
+    *
+    * - the same number of splits
+    * - reference the same accounts
+    * - have the same values in the splits
+    * - have a postDate wihtin 3 days
+    *
+    * @param transaction reference to the transaction to be checked
+    *                    against this transaction
+    * @retval true transactions are identical
+    * @retval false transactions are not identical
+    */
+  const bool isDuplicate(const MyMoneyTransaction& transaction) const;
+
+  /**
+    * This static method returns the id which will be assigned to the
+    * first split added to a transaction. This ID can be used to figure
+    * out the split that references the account through which a transaction
+    * was entered.
+    *
+    * @return QCString with ID of the first split of transactions
+    */
+  static const QCString firstSplitID(void);
+
 private:
   static const int SPLIT_ID_SIZE = 4;
 
@@ -193,12 +243,36 @@ private:
     */
   unsigned int m_nextSplitID;
 
+  /**
+    * This member keeps the base commodity (e.g. currency) for this transaction
+    */
+  QCString  m_commodity;
+
+  /**
+    * This member keeps the bank's unique ID for the transaction, so we can
+    * avoid duplicates.  This is only used for electronic statement downloads.
+    */
+  QString m_bankID;
+
 private:
   /**
     * This method returns the next id to be used for a split
     */
   const QCString nextSplitID(void);
 
+  /**
+    * This module implements an algorithm used by P.J. Weinberger
+    * for fast hashing. Source: COMPILERS by Alfred V. Aho,
+    * pages 435-437.
+    *
+    * It converts the string passed in @p txt into a non-unique
+    * unsigned long integer value.
+    *
+    * @param txt the text to be hashed
+    * @return non-unique hash value of the text @p txt
+    */
+  const unsigned long hash(const QString& txt) const;
+
   // friend QDataStream &operator<<(QDataStream &, const MyMoneyTransaction &);
   // friend QDataStream &operator>>(QDataStream &, MyMoneyTransaction &);
 
