@@ -1103,7 +1103,10 @@ void MyMoneySeqAccessMgr::loadAccount(const MyMoneyAccount& acc)
   }
   m_accountList[acc.id()] = acc;
 
-  m_balanceCache[acc.id()] = MyMoneyBalanceCacheItem(acc.openingBalance());
+ // FIXME: Since usage of openingBalance is deprecated, this whole code can go eventually
+ if(acc.accountType() != MyMoneyAccount::Stock
+ && acc.accountType() != MyMoneyAccount::Investment)
+   m_balanceCache[acc.id()] = MyMoneyBalanceCacheItem(acc.openingBalance());
 }
 
 void MyMoneySeqAccessMgr::loadTransaction(const MyMoneyTransaction& tr)
@@ -1681,15 +1684,18 @@ void MyMoneySeqAccessMgr::removePrice(const MyMoneyPrice& price)
   touch();
 }
 
-const MyMoneyPriceList MyMoneySeqAccessMgr::priceList(void) const
+const MyMoneyPriceList& MyMoneySeqAccessMgr::priceList(void) const
 {
   return m_priceList;
 }
 
-const MyMoneyPrice MyMoneySeqAccessMgr::price(const QCString& fromId, const QCString& toId, const QDate& date, const bool exactDate) const
-{
+MyMoneyPrice MyMoneySeqAccessMgr::price(const QCString& fromId, const QCString& toId, const QDate& _date, const bool exactDate) const{
   MyMoneyPrice rc;
   MyMoneyPriceEntries::ConstIterator it;
+  QDate date(_date);
+
+  if(!date.isValid())
+    date = QDate::currentDate();
 
   for(it = m_priceList[MyMoneySecurityPair(fromId, toId)].begin(); it != m_priceList[MyMoneySecurityPair(fromId, toId)].end(); ++it) {
     if(date < it.key())
