@@ -34,6 +34,8 @@
 #include "mymoneystoragedump.h"
 #include "imymoneystorage.h"
 #include "../mymoneyaccount.h"
+#include "../mymoneysecurity.h"
+#include "../mymoneyprice.h"
 
 MyMoneyStorageDump::MyMoneyStorageDump()
 {
@@ -64,17 +66,39 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
   s << "user e-mail = " << storage->userEmail() << "\n";
   s << "creation date = " << storage->creationDate().toString(Qt::ISODate) << "\n";
   s << "last modification date = " << storage->lastModificationDate().toString(Qt::ISODate) << "\n";
+  s << "base currency = " << storage->value("kmm-baseCurrency") << "\n";
   s << "\n";
-  
+
   s << "Internal-Info\n";
   s << "-------------\n";
-  s << "next account id     = " << _storage->accountId() << "\n";
-  s << "next transaction id = " << _storage->transactionId() << "\n";
-  s << "next payee id       = " << _storage->payeeId() << "\n";
-  s << "next institution id = " << _storage->institutionId() << "\n";
-  s << "next schedule id    = " << _storage->scheduleId() << "\n";
+  s << "accounts = " << _storage->accountList().count() <<", next id = " << _storage->accountId() << "\n";
+  MyMoneyTransactionFilter filter;
+  QValueList<MyMoneyTransaction> list_t = storage->transactionList(filter);
+  QValueList<MyMoneyTransaction>::ConstIterator it_t;
+  s << "transactions = " << list_t.count() << ", next id = " << _storage->transactionId() << "\n";
+  QMap<int,int> xferCount;
+  for(it_t = list_t.begin(); it_t != list_t.end(); ++it_t) {
+    QValueList<MyMoneySplit>::ConstIterator it_s;
+    int accountCount = 0;
+    for(it_s = (*it_t).splits().begin(); it_s != (*it_t).splits().end(); ++it_s) {
+      MyMoneyAccount acc = storage->account((*it_s).accountId());
+      if(acc.accountGroup() != MyMoneyAccount::Expense
+      && acc.accountGroup() != MyMoneyAccount::Income)
+        accountCount++;
+    }
+    if(accountCount > 1)
+      xferCount[accountCount] = xferCount[accountCount] + 1;
+  }
+  QMap<int,int>::ConstIterator it_cnt;
+  for(it_cnt = xferCount.begin(); it_cnt != xferCount.end(); ++it_cnt) {
+    s << "               " << *it_cnt << " of them references " << it_cnt.key() << " accounts\n";
+  }
+
+  s << "payees = " << _storage->payeeList().count() << ", next id = " << _storage->payeeId() << "\n";
+  s << "institutions = " << _storage->institutionList().count() << ", next id = " << _storage->institutionId() << "\n";
+  s << "schedules = " << _storage->scheduleList().count() << ", next id = " << _storage->scheduleId() << "\n";
   s << "\n";
-  
+
   s << "Institutions\n";
   s << "------------\n";
 
@@ -111,6 +135,7 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
   s << "--------" << "\n";
 
   QValueList<MyMoneyAccount> list_a = storage->accountList();
+  list_a.push_front(storage->equity());
   list_a.push_front(storage->expense());
   list_a.push_front(storage->income());
   list_a.push_front(storage->liability());
@@ -122,6 +147,15 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
     s << "  Number = " << (*it_a).number() << "\n";
     s << "  Description = " << (*it_a).description() << "\n";
     s << "  Type = " << (*it_a).accountType() << "\n";
+    if((*it_a).currencyId().isEmpty()) {
+      s << "  Currency = unknown\n";
+    } else {
+      if((*it_a).accountType() == MyMoneyAccount::Stock) {
+        s << "  Equity = " << storage->security((*it_a).currencyId()).name() << "\n";
+      } else {
+        s << "  Currency = " << storage->currency((*it_a).currencyId()).name() << "\n";
+      }
+    }
     s << "  Parent = " << (*it_a).parentAccountId();
     if(!(*it_a).parentAccountId().isEmpty()) {
       MyMoneyAccount parent = storage->account((*it_a).parentAccountId());
@@ -130,7 +164,7 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
       s << "n/a";
     }
     s << "\n";
-    
+
     s << "  Institution = " << (*it_a).institutionId();
     if(!(*it_a).institutionId().isEmpty()) {
       MyMoneyInstitution inst = storage->institution((*it_a).institutionId());
@@ -139,12 +173,12 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
       s << "n/a";
     }
     s << "\n";
-    
+
     s << "  Opening data = " << (*it_a).openingDate().toString(Qt::ISODate) << "\n";
     s << "  Opening balance = " << (*it_a).openingBalance().formatMoney() << "\n";
     s << "  Last modified = " << (*it_a).lastModified().toString(Qt::ISODate) << "\n";
     s << "  Last reconciled = " << (*it_a).lastReconciliationDate().toString(Qt::ISODate) << "\n";
-    
+
     s << "  KVP: " << "\n";
     QMap<QCString, QString>kvp = (*it_a).pairs();
     QMap<QCString, QString>::Iterator it;
@@ -165,12 +199,83 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
   }
   s << "\n";
 
+#if 0
+  s << "Currencies" << "\n";
+  s << "----------" << "\n";
+
+  QValueList<MyMoneyCurrency> list_c = storage->currencyList();
+  QValueList<MyMoneyCurrency>::ConstIterator it_c;
+  for(it_c = list_c.begin(); it_c != list_c.end(); ++it_c) {
+    s << "  Name = " << (*it_c).name() << "\n";
+    s << "    ID = " << (*it_c).id() << "\n";
+    s << "    Symbol = " << (*it_c).tradingSymbol() << "\n";
+    s << "    Parts/Unit = " << (*it_c).partsPerUnit() << "\n";
+    s << "    smallest cash fraction = " << (*it_c).smallestCashFraction() << "\n";
+    s << "    smallest account fraction = " << (*it_c).smallestAccountFraction() << "\n";
+    dumpPriceHistory(s, (*it_c).priceHistory());
+    s << "\n";
+  }
+  s << "\n";
+#endif
+
+  s << "Securities" << "\n";
+  s << "----------" << "\n";
+
+  QValueList<MyMoneySecurity> list_e = storage->securityList();
+  QValueList<MyMoneySecurity>::ConstIterator it_e;
+  for(it_e = list_e.begin(); it_e != list_e.end(); ++it_e) {
+    s << "  Name = " << (*it_e).name() << "\n";
+    s << "    ID = " << (*it_e).id() << "\n";
+    s << "    Market   = " << (*it_e).tradingMarket() << "\n";
+    s << "    Symbol   = " << (*it_e).tradingSymbol() << "\n";
+    s << "    Currency = " << (*it_e).tradingCurrency() << " (";
+    if((*it_e).tradingCurrency().isEmpty()) {
+      s << "unknown";
+    } else {
+      MyMoneySecurity tradingCurrency = storage->currency((*it_e).tradingCurrency());
+      if(!tradingCurrency.isCurrency()) {
+        s << "invalid currency: ";
+      }
+      s << tradingCurrency.name();
+    }
+    s << ")\n";
+
+    s << "    Type = " << securityTypeToString((*it_e).securityType()) << "\n";
+    s << "    smallest account fraction = " << (*it_e).smallestAccountFraction() << "\n";
+
+    s << "    KVP: " << "\n";
+    QMap<QCString, QString>kvp = (*it_e).pairs();
+    QMap<QCString, QString>::Iterator it;
+    for(it = kvp.begin(); it != kvp.end(); ++it) {
+      s << "      '" << it.key() << "' = '" << it.data() << "'\n";
+    }
+    s << "\n";
+  }
+  s << "\n";
+
+  s << "Prices" << "\n";
+  s << "--------" << "\n";
+
+  MyMoneyPriceList list_pr = _storage->priceList();
+  MyMoneyPriceList::ConstIterator it_pr;
+  for(it_pr = list_pr.begin(); it_pr != list_pr.end(); ++it_pr) {
+    s << "  From = " << it_pr.key().first << "\n";
+    s << "    To = " << it_pr.key().second << "\n";
+    MyMoneyPriceEntries::ConstIterator it_pre;
+    for(it_pre = (*it_pr).begin(); it_pre != (*it_pr).end(); ++it_pre) {
+      s << "      Date = " << (*it_pre).date().toString() << "\n";
+      s << "        Price = " << (*it_pre).rate().formatMoney("", 8) << "\n";
+      s << "        Source = " << (*it_pre).source() << "\n";
+      s << "        From = " << (*it_pre).from() << "\n";
+      s << "        To   = " << (*it_pre).to() << "\n";
+    }
+    s << "\n";
+  }
+  s << "\n";
+
   s << "Transactions" << "\n";
   s << "------------" << "\n";
 
-  MyMoneyTransactionFilter filter;
-  QValueList<MyMoneyTransaction> list_t = storage->transactionList(filter);
-  QValueList<MyMoneyTransaction>::ConstIterator it_t;
   for(it_t = list_t.begin(); it_t != list_t.end(); ++it_t) {
     dumpTransaction(s, storage, *it_t);
   }
@@ -219,7 +324,7 @@ void MyMoneyStorageDump::writeStream(QDataStream& _s, IMyMoneySerialize* _storag
       }
     }
     s << "  TRANSACTION\n";
-    dumpTransaction(s, storage, (*it_s).transaction());    
+    dumpTransaction(s, storage, (*it_s).transaction());
   }
   s << "\n";
 }
@@ -229,7 +334,9 @@ void MyMoneyStorageDump::dumpTransaction(QTextStream& s, IMyMoneyStorage* storag
   s << "  ID = " << it_t.id() << "\n";
   s << "  Postdate  = " << it_t.postDate().toString(Qt::ISODate) << "\n";
   s << "  EntryDate = " << it_t.entryDate().toString(Qt::ISODate) << "\n";
+  s << "  Commodity = [" << it_t.commodity() << "]\n";
   s << "  Memo = " << it_t.memo() << "\n";
+  s << "  BankID = " << it_t.bankID() << "\n";
   s << "  KVP: " << "\n";
   QMap<QCString, QString>kvp = it_t.pairs();
   QMap<QCString, QString>::Iterator it;
@@ -248,10 +355,16 @@ void MyMoneyStorageDump::dumpTransaction(QTextStream& s, IMyMoneyStorage* storag
     } else
       s << " ()\n";
     s << "    Account = " << (*it_s).accountId();
-    MyMoneyAccount acc = storage->account((*it_s).accountId());
-    s << " (" << acc.name() << ")" << "\n";
+    MyMoneyAccount acc;
+    try {
+      acc = storage->account((*it_s).accountId());
+      s << " (" << acc.name() << ") [" << acc.currencyId() << "]\n";
+    } catch (MyMoneyException *e) {
+      s << " (---) [---]\n";
+      delete e;
+    }
     s << "    Memo = " << (*it_s).memo() << "\n";
-    if((*it_s).value() == MyMoneyMoney::minValue + 1)
+    if((*it_s).value() == MyMoneyMoney::autoCalc)
       s << "    Value = will be calculated" << "\n";
     else
       s << "    Value = " << (*it_s).value().formatMoney() << "\n";
@@ -371,7 +484,7 @@ const QString MyMoneyStorageDump::paymentMethodToString(MyMoneySchedule::payment
       text = i18n("Other");
       break;
     case MyMoneySchedule::STYPE_WRITECHEQUE:
-      text = i18n("Write cheque");
+      text = i18n("Write check");
       break;
     case MyMoneySchedule::STYPE_ANY:
       text = i18n("Any (Error)");
@@ -383,7 +496,7 @@ const QString MyMoneyStorageDump::paymentMethodToString(MyMoneySchedule::payment
 const QString MyMoneyStorageDump::reconcileToString(MyMoneySplit::reconcileFlagE flag) const
 {
   QString rc;
-  
+
   switch(flag) {
     case MyMoneySplit::NotReconciled:
       rc = i18n("not reconciled");
@@ -403,3 +516,46 @@ const QString MyMoneyStorageDump::reconcileToString(MyMoneySplit::reconcileFlagE
   }
   return rc;
 }
+
+const QString MyMoneyStorageDump::securityTypeToString(const MyMoneySecurity::eSECURITYTYPE securityType)
+{
+  QString returnString;
+
+  switch (securityType)
+  {
+  case MyMoneySecurity::SECURITY_STOCK:
+    returnString = i18n("Stock");
+    break;
+  case MyMoneySecurity::SECURITY_MUTUALFUND:
+    returnString = i18n("Mutual Fund");
+    break;
+  case MyMoneySecurity::SECURITY_BOND:
+    returnString = i18n("Bond");
+    break;
+  case MyMoneySecurity::SECURITY_CURRENCY:
+    returnString = i18n("Currency");
+    break;
+  case MyMoneySecurity::SECURITY_NONE:
+    returnString = i18n("None");
+    break;
+  default:
+    returnString = i18n("Unknown");
+  }
+
+  return returnString;
+}
+#if 0
+void MyMoneyStorageDump::dumpPriceHistory(QTextStream& s, const equity_price_history history)
+{
+  if(history.count() != 0) {
+    s << "    Price History:\n";
+
+    equity_price_history::const_iterator it_price = history.begin();
+    while ( it_price != history.end() )
+    {
+      s << "      " << it_price.key().toString() << ": " << it_price.data().toDouble() << "\n";
+      it_price++;
+    }
+  }
+}
+#endif
