@@ -32,7 +32,7 @@
 // Project Includes
 
 #include "../mymoney/mymoneyobserver.h"
-class MyMoneyAccount;
+#include "../mymoney/mymoneyaccount.h"
 class MyMoneyInstitution;
 
 /**
@@ -61,7 +61,7 @@ class MyMoneyInstitution;
 class KAccountItem
 {
 public:
-  KAccountItem() {} ;
+  KAccountItem() { m_accountType = MyMoneyAccount::UnknownAccountType; }
   virtual ~KAccountItem() {};
 
   /**
@@ -69,8 +69,15 @@ public:
     *
     * @param id account id to be stored in m_accountID;
     */
-  void setAccountID(const QCString& id) { m_accountID = id; };
-        
+  void setAccountID(const QCString& id) { m_accountID = id; }
+
+  /**
+    * This method allows to set the account type.
+    *
+    * @param type accountTypeE to be stored in m_accountType
+    */
+  void setAccountType(const MyMoneyAccount::accountTypeE type) { m_accountType = type; }
+
   /**
     * This method returns the account's id for this object
     *
@@ -78,21 +85,28 @@ public:
     */
   const QCString accountID(void) const { return m_accountID; };
 
+  /**
+    * This method returns the account's type for this object
+    *
+    * @return const MyMoneyAccount::accountTypeE of the object
+    */
+  const MyMoneyAccount::accountTypeE accountType(void) const { return m_accountType; };
+
 private:
-  QCString    m_accountID;  
+  QCString                      m_accountID;
+  MyMoneyAccount::accountTypeE  m_accountType;
 };
 
 /**
   * This class represents an item in the account list view. It is used
-  * by the KAccountsView, the KCategoriesView and the KNewAccountWizard
-  * to select between the accounts.
+  * by the KAccountsView to select between the accounts.
   */
 class KAccountListItem : public KListViewItem, public KAccountItem, MyMoneyObserver
 {
 public:
 
   KAccountListItem(KListView *parent, const QString& txt);
-  
+
   /**
     * Constructor to be used to construct an institution entry
     * object.
@@ -110,7 +124,7 @@ public:
     *
     * @param parent pointer to the KListView object this entry should be
     *               added to.
-    * @param institution const reference to MyMoneyAccount for which
+    * @param account const reference to MyMoneyAccount for which
     *               the KListView entry is constructed
     */
   KAccountListItem(KListView *parent, const MyMoneyAccount& account);
@@ -121,7 +135,7 @@ public:
     *
     * @param parent pointer to the parent KAccountListView object this entry should be
     *               added to.
-    * @param institution const reference to MyMoneyAccount for which
+    * @param account const reference to MyMoneyAccount for which
     *               the KListView entry is constructed
     */
   KAccountListItem(KAccountListItem *parent, const MyMoneyAccount& account);
@@ -136,7 +150,7 @@ public:
   void paintCell(QPainter *p, const QColorGroup & cg, int column, int width, int align);
 
   void paintFocus(QPainter *p, const QColorGroup & cg, const QRect& rect);
-  
+
   /**
     * This method is called by the MyMoneyFile object, whenever the
     * account that is represented by this object changes within the
@@ -146,22 +160,19 @@ public:
     */
   void update(const QCString& id);
 
-  /**
-    * This function can be called to clean the cache at a defined
-    * location during program execution. It will be used by main()
-    * to avoid false error reports by the memory leakage checker.
-    */
-  static void cleanCache(void);
-
   /**
     */
   void suspendUpdate(const bool suspend) { m_suspendUpdate = suspend; };
-  
+
   /**
     * Override and do nothing
     **/
   void paintBranches(QPainter* p, const QColorGroup& cg, int w, int y, int h);
 
+  int compare(QListViewItem* i, int col, bool ascending) const;
+
+  void setValue(const MyMoneyMoney& value, const bool valid = true);
+
 private:
   /**
     * This method is a helper for the constructors that contains
@@ -171,22 +182,58 @@ private:
     */
   void newAccount(const MyMoneyAccount& account);
 
-  /**
-    * This function can be called to preload the cache at a defined
-    * location during program execution. It will be used by newAccount().
-    */
-  void loadCache(void);
+protected:
+  bool m_suspendUpdate;
+  bool m_valueValid;
 
 private:
   bool m_bViewNormal;
-  bool m_suspendUpdate;
   int m_nAccountColumn;
   int m_nInstitutionColumn;
-
-  static  QPixmap* accountPixmap;
 };
 
 
+/**
+  * This class represents an item in the category list view. It is used
+  * by the KCategoriesView to select between the accounts.
+  */
+class KCategoryListItem : public KAccountListItem
+{
+public:
+  /**
+    * Constructor to be used to construct an account entry
+    * object.
+    *
+    * @param parent pointer to the KListView object this entry should be
+    *               added to.
+    * @param account const reference to MyMoneyAccount for which
+    *               the KListView entry is constructed
+    */
+  KCategoryListItem(KListView *parent, const MyMoneyAccount& account) : KAccountListItem(parent, account) {};
+
+  /**
+    * Constructor to be used to construct an account entry
+    * object.
+    *
+    * @param parent pointer to the parent KAccountListView object this entry should be
+    *               added to.
+    * @param account const reference to MyMoneyAccount for which
+    *               the KListView entry is constructed
+    */
+  KCategoryListItem(KCategoryListItem *parent, const MyMoneyAccount& account) : KAccountListItem(parent, account) {};
+
+  ~KCategoryListItem() {};
+
+  /**
+    * This method is called by the MyMoneyFile object, whenever the
+    * account that is represented by this object changes within the
+    * MyMoneyFile engine.
+    *
+    * @param id reference to QCString of the account's id
+    */
+  void update(const QCString& id);
+};
+
 /**
   * This class represents an item in the account icon view. It is used
   * by the KAccountsView to select between the accounts using icons.
@@ -232,12 +279,12 @@ public:
     * use my own paint method
     */
   void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
-  
+
   /**
     * use my own backgroundColor method
     */
   const QColor backgroundColor();
-  
+
 private:
   QCString m_transactionId;
 };
