@@ -102,7 +102,7 @@ KAccountsView::KAccountsView(QWidget *parent, const char *name, bool bInstitutio
 
   connect(accountListView, SIGNAL(doubleClicked(QListViewItem*, const QPoint&, int)),
     this, SLOT(slotListDoubleClicked(QListViewItem*, const QPoint&, int)));
-  connect(accountIconView, SIGNAL(doubleClicked(QIconViewItem*)),
+  connect(accountIconView, SIGNAL(executed(QIconViewItem*)),
     this, SLOT(slotIconDoubleClicked(QIconViewItem*)));
 
   connect(accountTabWidget, SIGNAL(currentChanged(QWidget*)),
@@ -544,7 +544,7 @@ void KAccountsView::refresh(const QCString& selectAccount)
           accountItem->setText(1, QString("%1").arg(m_transactionCountMap[*it]));
 
           if(m_accountMap[*it].accountType() == MyMoneyAccount::Investment) {
-            balance += file->totalValue(*it);
+            balance += file->totalValue(*it, QDate::currentDate());
             if(!file->totalValueValid(*it))
               balanceValid = false;
           } else {
@@ -721,33 +721,34 @@ void KAccountsView::refresh(const QCString& selectAccount)
 
 const bool KAccountsView::showSubAccounts(const QCStringList& accounts, KAccountListItem *parentItem, const bool used)
 {
-  bool  accountUsed = used;
+  bool accountUsed = used;
 
   for ( QCStringList::ConstIterator it = accounts.begin(); it != accounts.end(); ++it ) {
-
+    bool thisAccountUsed = used;
     // don't show stock accounts in non-expert mode
     if((m_accountMap[*it].accountType() == MyMoneyAccount::Stock)
     && !KMyMoneyUtils::isExpertMode())
       continue;
 
-    KAccountListItem *accountItem  = new KAccountListItem(parentItem,
-          m_accountMap[*it]);
+    KAccountListItem *accountItem  = new KAccountListItem(parentItem, m_accountMap[*it]);
 
-    accountItem->setText(1, QString("%1").arg(m_transactionCountMap[*it]));
+    accountItem->setText(1, QString("%1").arg(m_transactionCountMap[*it])); //?
 
-    accountUsed |= (m_transactionCountMap[*it] > 0);
+    thisAccountUsed |= (m_transactionCountMap[*it] > 0);
 
     QCStringList subAccounts = m_accountMap[*it].accountList();
     if (subAccounts.count() >= 1) {
-      accountUsed |= showSubAccounts(subAccounts, accountItem, used) || m_transactionCountMap[*it] > 0;
+      thisAccountUsed |= showSubAccounts(m_accountMap[*it].accountList(), accountItem, used);
     }
 
-    if(accountUsed == false && m_hideCategory == true) {
-      // in case hide category is on and the account or any of it's
-      // subaccounts has no split, we can safely remove it and all
+    if(thisAccountUsed == false && m_hideCategory == true) {
+      // in case hide category is on and the account nor any of it's
+      // subaccounts has a split, we can safely remove it and all
       // it's sub-ordinate accounts from the list
       delete accountItem;
+      m_hiddenCategories->show();
     }
+    accountUsed |= thisAccountUsed;
   }
   return accountUsed;
 }
