@@ -132,14 +132,18 @@ int KTransactionPtrVector::compareItems(KTransactionPtrVector::Item d1, KTransac
       case SortEntryDate:
         rc = t2->entryDate().daysTo(t1->entryDate());
         if(rc == 0) {
-          // same date? Sort by value
-          rc = 1;
-          tmp = s2.value() - s1.value();
-          if(tmp.isZero()) {
-            // same value? sort by id
-            rc = compareItems(t1->id(), t2->id());
-          } else if(tmp.isNegative()) {
-            rc = -1;
+          // on same day, lower check numbers show up first
+          rc = compareItems(s1.number(), s2.number());
+          if(rc == 0) {
+            // same number (e.g. empty)? larger amounts show up first
+            rc = 1;
+            tmp = s2.value() - s1.value();
+            if(tmp.isZero()) {
+              // same value? Sort by id
+              rc = compareItems(t1->id(), t2->id());
+            } else if(tmp.isNegative()) {
+              rc = -1;
+            }
           }
         }
         break;
@@ -220,14 +224,18 @@ int KTransactionPtrVector::compareItems(KTransactionPtrVector::Item d1, KTransac
         // sort by post date
         rc = t2->postDate().daysTo(t1->postDate());
         if(rc == 0) {
-          // on same day, larger amounts show up first
-          rc = 1;
-          tmp = s2.value() - s1.value();
-          if(tmp.isZero()) {
-            // same value? Sort by id
-            rc = compareItems(t1->id(), t2->id());
-          } else if(tmp.isNegative()) {
-            rc = -1;
+          // on same day, lower check numbers show up first
+          rc = compareItems(s1.number(), s2.number());
+          if(rc == 0) {
+            // same number (e.g. empty)? larger amounts show up first
+            rc = 1;
+            tmp = s2.value() - s1.value();
+            if(tmp.isZero()) {
+              // same value? Sort by id
+              rc = compareItems(t1->id(), t2->id());
+            } else if(tmp.isNegative()) {
+              rc = -1;
+            }
           }
         }
         break;
@@ -396,6 +404,7 @@ void KLedgerView::refreshView(const bool transactionFormVisible)
   config->setGroup("List Options");
   QDateTime defaultDate;
   m_dateStart = config->readDateTimeEntry("StartDate", &defaultDate).date();
+  m_hideReconciledTransactions = config->readBoolEntry("HideReconciledTransactions", false);
 
   m_register->readConfig();
 
@@ -410,8 +419,13 @@ void KLedgerView::refreshView(const bool transactionFormVisible)
     if(m_inReconciliation == true) {
       filter.addState(MyMoneyTransactionFilter::notReconciled);
       filter.addState(MyMoneyTransactionFilter::cleared);
-    } else
+    } else {
       filter.setDateFilter(m_dateStart, QDate());
+      if (m_hideReconciledTransactions) {
+        filter.addState(MyMoneyTransactionFilter::notReconciled);
+        filter.addState(MyMoneyTransactionFilter::cleared);
+      }
+    }
 
     // get the list of transactions
     QValueList<MyMoneyTransaction> list = file->transactionList(filter);
@@ -704,6 +718,11 @@ void KLedgerView::slotPayeeChanged(const QString& name)
             // ok, we found a previous transaction. now we clear out
             // what we have collected so far and add those splits from
             // the previous transaction
+            //
+            // If a check number is already specified by the user it is
+            // used. If the input field is empty and the previous transaction
+            // contains a checknumber, the next usuable check no will be assigned
+            // to the transaction.
             MyMoneyTransaction t = list.last();
             m_transaction.removeSplits();
             QValueList<MyMoneySplit>::ConstIterator it;
@@ -711,9 +730,13 @@ void KLedgerView::slotPayeeChanged(const QString& name)
               MyMoneySplit s(*it);
               s.setReconcileFlag(MyMoneySplit::NotReconciled);
               s.setId(QCString());
-              if(!s.number().isEmpty()) {
-                unsigned64 no = MyMoneyFile::instance()->highestCheckNo(s.accountId()).toULongLong();
-                s.setNumber(QString::number(no+1));
+              if(s.accountId() == m_account.id()) {
+                if(m_editNr && !m_editNr->text().isEmpty()) {
+                  s.setNumber(m_editNr->text());
+                } else if(!s.number().isEmpty()) {
+                  unsigned64 no = MyMoneyFile::instance()->highestCheckNo(s.accountId()).toULongLong();
+                  s.setNumber(QString::number(no+1));
+                }
               }
               m_transaction.addSplit(s);
             }
@@ -843,6 +866,7 @@ void KLedgerView::amountChanged(const QString& value, int dir)
     if(m_account.value("NoVat") == "Yes")
       checkVat = false;
 
+    m_split.setShares(val);
     // set either shares or value depending on the currencies
     m_split.setValue(val, m_transaction.commodity(), m_account.currencyId());
 
@@ -852,11 +876,11 @@ void KLedgerView::amountChanged(const QString& value, int dir)
     if(m_transaction.commodity() != m_account.currencyId() && !price.isZero())
       m_split.setValue(val / price);
 
+    m_transaction.modifySplit(m_split);
+
     if(m_editAmount)
       m_editAmount->loadText(val.abs().formatMoney(""));
 
-    m_transaction.modifySplit(m_split);
-
     // let's take care of the other half of the transaction
     if(m_transaction.splitCount() == 2) {
       // initialize in case we don't find it later on
@@ -1380,6 +1404,74 @@ void KLedgerView::slotStartEdit(void)
   enableCancelButton(true);
   enableMoreButton(true);
 
+  // If we deal with multiple currencies we make sure, that for
+  // transactions with two splits, the transaction's commodity is the
+  // currency of the currently selected account. This saves us from a
+  // lot of grieve later on.
+  // Editing a transaction which has more than two splits and a commodity
+  // that differs from the currency of the current selected account is
+  // not a good idea. We will warn the user and give him a hint if there
+  // is an account where he can perfom the edit operation much better.
+  if(m_transaction.commodity() != m_account.currencyId()) {
+    if(m_transaction.splitCount() == 2) {
+      // in case of two splits, it's easy. We just have to switch the
+      // transactions commodity. Let's assume the following scenario:
+      // - transactions commodity is CA
+      // - account's currencyId is CB
+      // - second split is of course in CA (otherwise we have a real problem)
+      // - Value is V in both splits
+      // - Shares in this account's split is SB
+      // - Shares in the other account's split is SA (and equal to V)
+      //
+      // We do the following:
+      // - change transactions commodity to CB
+      // - set V in both splits to SB
+      // - modify the splits in the transaction
+      try {
+        MyMoneySplit split = m_transaction.splitByAccount(m_account.id(), false);
+        m_transaction.setCommodity(m_account.currencyId());
+        m_split.setValue(m_split.shares());
+        split.setValue(-m_split.shares());
+        m_transaction.modifySplit(m_split);
+        m_transaction.modifySplit(split);
+
+        if(m_transactionPtr) {
+          KMyMoneyTransaction k(m_transaction);
+          k.setSplitId(m_split.id());
+          *m_transactionPtr = k;
+        }
+      } catch(MyMoneyException *e) {
+        qDebug("Unable to update commodity to second splits currency in %s: '%s'", m_transaction.id().data(), e->what().data());
+        delete e;
+      }
+
+    } else {
+      // Find a suitable account
+      MyMoneySecurity sec = MyMoneyFile::instance()->currency(m_transaction.commodity());
+      MyMoneyAccount acc;
+      for(it = m_transaction.splits().begin(); it != m_transaction.splits().end(); ++it) {
+        if((*it).id() == m_split.id())
+          continue;
+        acc = MyMoneyFile::instance()->account((*it).accountId());
+        if((acc.accountGroup() == MyMoneyAccount::Asset
+        || acc.accountGroup() == MyMoneyAccount::Liability)
+        && acc.accountType() != MyMoneyAccount::Stock) {
+          if(m_transaction.commodity() == acc.currencyId())
+            break;
+        }
+        acc = MyMoneyAccount();
+      }
+      QString msg;
+      msg = QString("<p>")+i18n("This transaction has more than two splits and is based on a different currency (%1). Using this account to modify the transaction is currently not very well supported by KMyMoney and may result in false results.").arg(sec.name())+QString(" ");
+      if(acc.id().isEmpty()) {
+        msg += i18n("KMyMoney was not able to find a more appropriate account to edit this transaction. Nevertheless, you are allowed to modify the transaction. If you don't want to edit this transaction, please cancel from editing next.");
+      } else {
+         msg += i18n("Using e.g. <b>%1</b> to edit this transaction is a better choice. Nevertheless, you are allowed to modify the transaction. If you want to use the suggested account instead, please cancel from editing next and change the view to the suggested account.").arg(acc.name());
+      }
+      KMessageBox::information(0, msg);
+    }
+  }
+
   showWidgets();
 
   m_form->tabBar()->blockSignals(true);
@@ -1517,6 +1609,15 @@ void KLedgerView::slotEndEdit(void)
             toValue = (*it).shares();
           }
 
+          // make sure either to and from are zero or both are not zero
+          if((fromValue.isZero() && !toValue.isZero())
+          || (!fromValue.isZero() && toValue.isZero())) {
+            if(fromValue.isZero())
+              fromValue = toValue;
+            if(toValue.isZero())
+              toValue = fromValue;
+          }
+
           KCurrencyCalculator calc(fromCurrency,
                                    toCurrency,
                                    fromValue,
@@ -1532,7 +1633,6 @@ void KLedgerView::slotEndEdit(void)
         } else {
           price = (*it_p);
         }
-
         // update shares if the transaction commodity is the currency
         // of the current selected account
         if(m_transaction.commodity() == m_account.currencyId()) {
@@ -1976,25 +2076,13 @@ void KLedgerView::slotCreateSchedule(void)
 {
   if (!m_transaction.id().isEmpty()) {
     MyMoneySchedule schedule;
-    MyMoneySchedule::typeE scheduleType = MyMoneySchedule::TYPE_ANY;
-
-    if(m_account.accountGroup() == MyMoneyAccount::Asset) {
-      if(!m_split.value().isNegative())
-        scheduleType = MyMoneySchedule::TYPE_DEPOSIT;
-      else
-        scheduleType = MyMoneySchedule::TYPE_BILL;
-    } else {
-      if(!m_split.value().isNegative())
-        scheduleType = MyMoneySchedule::TYPE_BILL;
-      else
-        scheduleType = MyMoneySchedule::TYPE_DEPOSIT;
-    }
-    if(m_transaction.splitCount() == 2
-    && m_split.action() == MyMoneySplit::ActionTransfer)
-      scheduleType = MyMoneySchedule::TYPE_TRANSFER;
-
-    // create a copy and reset all flags
+    
+    // create a copy of the transaction and reset reconcile flags
+    // check if this is a transfer, coz use of action types in splits is now deprecated (apparently)
     MyMoneyTransaction t;
+    bool potentialTransfer = true;
+    MyMoneyFile* file = MyMoneyFile::instance();
+    
     try {
       t = m_transaction;
       QValueList<MyMoneySplit> list = t.splits();
@@ -2004,6 +2092,9 @@ void KLedgerView::slotCreateSchedule(void)
         s.setReconcileDate(QDate());
         s.setReconcileFlag(MyMoneySplit::NotReconciled);
         t.modifySplit(s);
+        if ((file->account(s.accountId()).accountGroup() != MyMoneyAccount::Asset) &&
+             (file->account(s.accountId()).accountGroup() != MyMoneyAccount::Liability))
+          potentialTransfer = false;
       }
     } catch (MyMoneyException *e) {
       qDebug("Unable to reset flags in %s(%d):'%s'", __FILE__, __LINE__, e->what().latin1());
@@ -2011,12 +2102,21 @@ void KLedgerView::slotCreateSchedule(void)
     }
     schedule.setTransaction(t);
 
-    // FIXME: For some reason, the action field is empty for some deposit transactions.
-    QCString action = m_transaction.splitByAccount(m_account.id()).action();
-    if(action.isEmpty()) {
-      action = MyMoneySplit::ActionDeposit;
+    // take 'action' value from 'this' account's split, or, if it's blank, work it out from the sign
+    QCString action;
+    MyMoneySplit s = m_transaction.splitByAccount(m_account.id());
+    action = s.action();
+    if (action.isEmpty()) {
+      if ((potentialTransfer) && (t.splitCount() == 2)) {
+        action = MyMoneySplit::ActionTransfer;
+      } else {
+        if (s.value().isNegative())
+          action = MyMoneySplit::ActionWithdrawal;
+        else
+          action = MyMoneySplit::ActionDeposit;
+      }
     }
-
+    // display the dialog and await response
     KEditScheduleDialog *m_keditscheddlg = new KEditScheduleDialog(action,
       schedule, this);
 
