@@ -31,6 +31,7 @@
 // ----------------------------------------------------------------------------
 // KDE Includes
 
+#include "kdecompat.h"
 #include <klineedit.h>
 
 // ----------------------------------------------------------------------------
@@ -39,11 +40,25 @@
 
 #include "../mymoney/mymoneyaccount.h"
 #include "../kmymoneyutils.h"
+class kMyMoneyAccountCompletion;
 
 /**
-  *@author Thomas Baumgart
+  * @author Thomas Baumgart
   */
 
+/**
+  * This class implements a text based account/category selector. The name
+  * is kept for historic reasons. When initially used, the widget has the
+  * functionality of a KLineEdit object. Whenever a key is pressed, the set
+  * of account is searched for accounts which match the currently entered
+  * text.
+  *
+  * If any match is found a list selection box is opened and the user can use
+  * the up/down, page-up/page-down keys or the mouse to navigate in the list. If
+  * an account is selected, the selection box is closed. Other key-strokes are
+  * directed to the KLineEdit object to manipulate the text. With every key-stroke
+  * the selection box is updated.
+  */
 class kMyMoneyCategory : public KLineEdit
 {
    Q_OBJECT
@@ -51,26 +66,29 @@ public:
   kMyMoneyCategory(QWidget *parent=0, const char *name=0, const KMyMoneyUtils::categoryTypeE = static_cast<KMyMoneyUtils::categoryTypeE>(KMyMoneyUtils::expense | KMyMoneyUtils::income));
   ~kMyMoneyCategory();
 
-  void loadList(const KMyMoneyUtils::categoryTypeE type);
-
-  /**
-    */
-  void resetText(void);
-
   virtual bool eventFilter(QObject * , QEvent * );
 
+  kMyMoneyAccountCompletion* selector(void) const { return m_accountSelector; };
+
+  QCString selectedAccountId() const { return m_id; }
+
 signals:
   /**
     * This signal is emitted, when a new category name has been
     * entered by the user and this name is not known as account
     * by the MyMoneyFile object.
     */
-  void newCategory(const QString& category);
+  // void newCategory(const QString& category);
 
   /**
     * This signal is emitted when the user selected a different category.
     */
-  void categoryChanged(const QString& category);
+  // void categoryChanged(const QString& category);
+
+  /**
+    * This signal is emitted when the user selected a different account/category.
+    */
+  void categoryChanged(const QCString& id);
 
   /**
     * This signal is emitted when the user presses RETURN while editing
@@ -84,29 +102,56 @@ signals:
 
   void signalFocusIn(void);
 
-protected:
-  void focusOutEvent(QFocusEvent *ev);
-  void focusInEvent(QFocusEvent *ev);
-
 public slots:
+  /**
+    * Load the widget with the text given in the parameter @p text.
+    * This should not be used to load the name of an account/category
+    * but only for fixed text, e.g. 'Split transaction'.
+    *
+    * @param text text which should be loaded into the widget.
+    */
   void loadText(const QString& text);
 
+  /**
+    * Load the widget with the account identified by the parameter @p id.
+    * This should not be used to load the name of an account/category
+    * but only for fixed text, e.g. 'Split transaction'.
+    *
+    * @param id the id of the category/account that should be loaded
+    */
+  void loadAccount(const QCString& id);
+
+  /**
+    * Load the widget with the name of the account given by
+    * the parameter @p id.
+    *
+    * @param id id of account of which the name should be loaded
+    */
+  void slotSelectAccount(const QCString& id);
+
 protected:
   virtual void keyPressEvent( QKeyEvent * );
+  void focusOutEvent(QFocusEvent *ev);
+  void focusInEvent(QFocusEvent *ev);
 
 private:
-  void addCategories(QStringList& strList, const QCString& id, const QString& leadIn);
+  void checkForNewCategory(void);
 
 private:
   /**
     * This member keeps the initial value. It is used during
     * resetText() to set the widgets text back to this initial value
     */
-  QString m_text;
+  QString                    m_text;
 
-  QValueList<MyMoneyAccount> m_accountList;
-  QMap<QString, QCString>  m_categoryConversionList;
+  /**
+    * This member keeps the id of the selected category/account.
+    */
+  QCString                   m_id;
 
+  kMyMoneyAccountCompletion* m_accountSelector;
+  bool                       m_inCreation;
+  bool                       m_displayOnly;
 };
 
 #endif
