@@ -53,6 +53,7 @@
 
 // ----------------------------------------------------------------------------
 // KDE Includes
+#include "kdecompat.h"
 #include <kdatetbl.h> // Use the classes available for maximum re-use
 #include <kglobal.h>
 #include <kglobalsettings.h>
@@ -60,7 +61,9 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <knotifyclient.h>
-#include <kdeversion.h>
+#if KDE_IS_VERSION(3,2,0)
+#include <kcalendarsystem.h>
+#endif
 
 // ----------------------------------------------------------------------------
 // Project Includes
@@ -71,7 +74,7 @@ kMyMoneyDateTbl::kMyMoneyDateTbl(QWidget *parent, QDate date_, const char* name,
 {
   // call this first to make sure that member variables are initialized
   setType(MONTHLY);
-  
+
   setFontSize(10);
 
   if(!date_.isValid())
@@ -83,7 +86,7 @@ kMyMoneyDateTbl::kMyMoneyDateTbl(QWidget *parent, QDate date_, const char* name,
 
 
   viewport()->setEraseColor(KGlobalSettings::baseColor());
-  
+
   setDate(date_); // this initializes firstday, numdays, numDaysPrevMonth
 
   // So we can emit hoverDate
@@ -102,10 +105,10 @@ kMyMoneyDateTbl::paintCell(QPainter *painter, int row, int col)
   QBrush brushBlue(KGlobalSettings::activeTitleColor());
   QBrush brushLightblue(KGlobalSettings::baseColor());
   QFont font=KGlobalSettings::generalFont();
-  
+
   // -----
   font.setPointSize(fontsize);
-  
+
 #if KDE_VERSION < 310
   int firstWeekDay = KGlobal::locale()->weekStartsMonday() ? 1 : 0;
 #else
@@ -121,9 +124,9 @@ kMyMoneyDateTbl::paintCell(QPainter *painter, int row, int col)
       bool normalday = true;
       QString daystr;
       if ( col+firstWeekDay < 8 )
-        daystr = KGlobal::locale()->weekDayName(col+firstWeekDay, true);
+        daystr = WEEK_DAY_NAME(col+firstWeekDay, true);
       else
-        daystr = KGlobal::locale()->weekDayName(col+firstWeekDay-7, true);
+        daystr = WEEK_DAY_NAME(col+firstWeekDay-7, true);
 
       if ( daystr==i18n("Sunday", "Sun") || daystr==i18n("Saturday", "Sat") )
         normalday=false;
@@ -175,7 +178,7 @@ kMyMoneyDateTbl::paintCell(QPainter *painter, int row, int col)
       headerText = i18n("Week %1 for year %2.")
         .arg(weekStr)
         .arg(yearStr);
-#endif        
+#endif
 
       painter->drawText(0, 0, w, h-1, AlignCenter, headerText, -1, &rect);
 
@@ -343,10 +346,10 @@ kMyMoneyDateTbl::setFontSize(int size)
   // ----- find largest day name:
   maxCell.setWidth(0);
   maxCell.setHeight(0);
-  
+
   for(count=0; count<m_colCount; ++count)
   {
-    rect=metrics.boundingRect(KGlobal::locale()->weekDayName(count+1, true));
+    rect=metrics.boundingRect(WEEK_DAY_NAME(count+1, true));
     maxCell.setWidth(QMAX(maxCell.width(), rect.width()));
     maxCell.setHeight(QMAX(maxCell.height(), rect.height()));
   }
@@ -437,7 +440,7 @@ kMyMoneyDateTbl::contentsMouseReleaseEvent(QMouseEvent *e)
   {
     int dayOfWeek = date.dayOfWeek();
     int diff;
-    
+
     if (row < dayOfWeek)
     {
       diff = -(dayOfWeek - row);
@@ -555,7 +558,7 @@ void kMyMoneyDateTbl::setType(calendarType type)
     m_rowCount = m_colCount = 7;
     m_type = MONTHLY;
   }
-  
+
   setNumRows(m_rowCount);
   setNumCols(m_colCount);
   setHScrollBarMode(AlwaysOff);
@@ -643,7 +646,7 @@ void kMyMoneyDateTbl::contentsMouseMoveEvent(QMouseEvent* e)
     m_drawDateOrig = drawDate;
     emit hoverDate(drawDate);
   }
-  
+
   QGridView::contentsMouseMoveEvent(e);
 }
 
@@ -688,6 +691,8 @@ int kMyMoneyDateTbl::weekNumber(const QDate& date, int *yearNumber) const
     if ( yearNumber )
         *yearNumber = yearNum;
     return weekNum;
- 
+
 }
 #endif
+
+#include "kmymoneydatetbl.moc"
