@@ -38,14 +38,14 @@
 
 
 /**
-  *@author Thomas Baumgart
+  * @author Thomas Baumgart
   */
-
-class kMyMoneyPayee : public KLineEdit {
-   Q_OBJECT
-public: 
-	kMyMoneyPayee(QWidget *parent=0, const char *name=0);
-	~kMyMoneyPayee();
+class kMyMoneyPayee : public KLineEdit
+{
+  Q_OBJECT
+public:
+  kMyMoneyPayee(QWidget *parent=0, const char *name=0);
+  ~kMyMoneyPayee();
 
   /**
     * This method is used to load the combo box from the
@@ -59,8 +59,6 @@ public:
     */
   void resetText(void);
 
-  virtual bool eventFilter(QObject * , QEvent * );
-
 public slots:
   /**
     * This slot is used to load the local text copy and the widget with
@@ -86,16 +84,6 @@ signals:
     */
   void payeeChanged(const QString& payee);
 
-  /**
-    * This signal is emitted when the user presses RETURN while editing
-    */
-  void signalEnter();
-
-  /**
-    * This signal is emitted when the user presses ESC while editing
-    */
-  void signalEsc();
-
 protected:
   void focusOutEvent(QFocusEvent *ev);
   virtual void keyPressEvent( QKeyEvent * );
