@@ -29,6 +29,7 @@
 #include <qwidget.h>
 #include <qpainter.h>
 #include <qtable.h>
+#include <qtimer.h>
 
 // #include <qfontmetric.h>
 
@@ -69,7 +70,7 @@ public:
     *         0 will be returned.
     */
   virtual KMyMoneyTransaction* transaction(const int idx) const = 0;
-  
+
   /**
     * This method returns the id of the account that should be
     * shown by the view. The implementation depends on the type of view
@@ -97,6 +98,11 @@ public:
     *         accounts, the sign will be inverted for display purposes.
     */
   virtual const MyMoneyMoney balance(const int idx) const = 0;
+
+  /**
+    */
+  virtual bool focusNextPrevChild(bool next) = 0;
+
 };
 
 class kMyMoneyRegister : public QTable
@@ -247,6 +253,16 @@ public:
     */
   void setAction(const QCString& action, const QString& txt);
 
+  /**
+    * This method tells the caller, if a given row belongs
+    * to the current transaction or not.
+    *
+    * @param row the row in question
+    * @retval false @p row belongs to the current transaction
+    * @retval true @p row belongs to a different transaction
+    */
+  bool differentTransaction(int row) const;
+
 public slots:
   /**
     * This method is used to inform the widget about the number
@@ -259,23 +275,6 @@ public slots:
     */
   void setTransactionCount(const int transactions, const bool setCurrentTransaction = true);
 
-  /**
-    * This method allows to modify the color for erronous transactions.
-    * Calling it repetetively with inverted values for the parameter @p on
-    * toggles the color for erronous transactions
-    * between the configured text color and red.
-    *
-    * @param on if true, erronous transaction will be shown in red. If false,
-    *           erronous transactions will be shown in the configured text
-    *           color as all other transactions.
-    *
-    * @note Erronous transactions are those, that have less than 1 split
-    *       or where the sum of all splits does not equal 0. This definition
-    *       is checked in e.g. kMyMoneyRegisterCheckings::paintCell(). The
-    *       check must be implemented by any class derived from this class.
-    */
-  void slotSetErrorColor(const bool on);
-
   virtual void setNumRows(int r);
 
   /**
@@ -286,12 +285,24 @@ public slots:
     */
   virtual void setNumCols(int r);
 
+  /**
+    * This method allows to blink erronous transactions in the ledger.
+    * Calling it repetetively toggles the color for erronous transactions
+    * between the configured text color and red.
+    *
+    * @note Erronous transactions are those, that have less than 1 split
+    *       or where the sum of all splits does not equal 0. This definition
+    *       is checked in e.g. kMyMoneyRegisterCheckings::paintCell(). The
+    *       check must be implemented by any class derived from this class.
+    */
+  void slotBlinkInvalid(void);
+
 protected:
   /**
     * The paint method must be provided by the derived class.
     */
   void paintCell(QPainter *p, int row, int col, const QRect& r, bool selected, const QColorGroup& cg) = 0;
-  
+
   void paintCell(QPainter *p, int row, int col, const QRect& r, bool selected, const QColorGroup& cg, const QString& txt, const int align);
 
   /**
@@ -306,7 +317,7 @@ protected:
     *       paintCell before m_transactionRow can be used.
     */
   void setTransactionRow(const int row);
-  
+
   /**
     * resizeData is re-implemented to avoid creation
     * of huge arrays that are not required
@@ -320,6 +331,10 @@ protected:
 
   virtual const bool isEditable(void) const { return true; };
 
+  bool focusNextPrevChild(bool next);
+
+  int transactionIndex(const int row) const;
+
 protected:
   int    m_rpt;     // current rows per transaction
   bool   m_ledgerLens;
@@ -334,9 +349,9 @@ protected:
   QColor m_textColor;
   QColor m_bgColor;
   QColor m_gridColor;
-  QColor m_errorColor;
+  QColor m_errorColor, m_lastErrorColor;
   QColor m_importColor;
-  
+
   bool   m_showGrid;
   bool   m_colorPerTransaction;
 
@@ -400,7 +415,7 @@ protected:
     * the setAction() method.
     */
   QMap<QCString, QString> m_action;
-  
+
 private:
   /**
     * This method is used to update all horizontal headers to the
@@ -422,6 +437,8 @@ private:
     */
   int    m_maxRpt;
 
+  QTimer  m_blinkTimer;
+
 signals:
   void signalPreviousTransaction();
   void signalNextTransaction();
@@ -430,21 +447,11 @@ signals:
     * This signal is emitted when the user presses the 'Home' or 'End' key
     */
   void signalSelectTransaction(const QCString&);
-  
+
   /**
     * This signal is emitted when the user presses DELETE
     */
   void signalDelete();
-  
-  /**
-    * This signal is emitted when the user presses RETURN
-    */
-  void signalEnter();
-
-  /**
-    * This signal is emitted when the user presses ESC
-    */
-  void signalEsc();
 
   /**
     * This signal is emitted when the user presses SPACE
